@@ -1,13 +1,15 @@
 # (c) 2018 Red Hat Inc.
-# GNU General Public License v3.0+ (see COPYING or https://www.gnu.org/licenses/gpl-3.0.txt)
+# GNU General Public License v3.0+ (see LICENSES/GPL-3.0-or-later.txt or https://www.gnu.org/licenses/gpl-3.0.txt)
+# SPDX-License-Identifier: GPL-3.0-or-later
 
 from __future__ import absolute_import, division, print_function
 
 __metaclass__ = type
 
 DOCUMENTATION = """
-author: Ansible Networking Team
-connection: httpapi
+author:
+ - Ansible Networking Team (@ansible-network)
+name: httpapi
 short_description: Use httpapi to run command on network appliances
 description:
 - This connection plugin provides a connection to remote devices over a HTTP(S)-based
@@ -16,30 +18,13 @@ version_added: 1.0.0
 extends_documentation_fragment:
 - ansible.netcommon.connection_persistent
 options:
-  import_modules:
-    type: boolean
-    description:
-    - Reduce CPU usage and network module execution time
-      by enabling direct execution. Instead of the module being packaged
-      and executed by the shell, it will be directly executed by the Ansible
-      control node using the same python interpreter as the Ansible process.
-      Note- Incompatible with C(asynchronous mode).
-      Note- Python 3 and Ansible 2.9.16 or greater required.
-      Note- With Ansible 2.9.x fully qualified modules names are required in tasks.
-    default: false
-    ini:
-    - section: ansible_network
-      key: import_modules
-    env:
-    - name: ANSIBLE_NETWORK_IMPORT_MODULES
-    vars:
-    - name: ansible_network_import_modules
   host:
     description:
     - Specifies the remote device FQDN or IP address to establish the HTTP(S) connection
       to.
     default: inventory_hostname
     vars:
+    - name: inventory_hostname
     - name: ansible_host
   port:
     type: int
@@ -160,8 +145,8 @@ from ansible.module_utils.six.moves import cPickle
 from ansible.module_utils.six.moves.urllib.error import HTTPError, URLError
 from ansible.module_utils.urls import open_url
 from ansible.playbook.play_context import PlayContext
-from ansible.plugins.loader import httpapi_loader
 from ansible.plugins.connection import ensure_connect
+from ansible.plugins.loader import httpapi_loader
 from ansible_collections.ansible.netcommon.plugins.plugin_utils.connection_base import (
     NetworkConnectionBase,
 )
@@ -271,7 +256,7 @@ class Connection(NetworkConnectionBase):
         super(Connection, self).close()
 
     @ensure_connect
-    def send(self, path, data, **kwargs):
+    def send(self, path, data, retries=None, **kwargs):
         """
         Sends the command to the device over api
         """
@@ -302,11 +287,15 @@ class Connection(NetworkConnectionBase):
         except HTTPError as exc:
             is_handled = self.handle_httperror(exc)
             if is_handled is True:
-                return self.send(path, data, **kwargs)
-            elif is_handled is False:
+                if retries is None:
+                    # The default behavior, retry indefinitely until timeout.
+                    return self.send(path, data, **kwargs)
+                if retries:
+                    return self.send(path, data, retries=retries - 1, **kwargs)
                 raise
-            else:
-                response = is_handled
+            if is_handled is False:
+                raise
+            response = is_handled
         except URLError as exc:
             raise AnsibleConnectionFailure(
                 "Could not connect to {0}: {1}".format(
