@@ -5,6 +5,7 @@
 
 from __future__ import absolute_import, division, print_function
 
+
 __metaclass__ = type
 
 """
@@ -15,26 +16,18 @@ the given network resource.
 """
 
 import re
-from ansible_collections.ansible.netcommon.plugins.module_utils.network.common.network_template import (
+
+from ansible_collections.ansible.netcommon.plugins.module_utils.network.common.rm_base.network_template import (
     NetworkTemplate,
 )
 
 
-def _tmplt_ospf_interface(config_data):
-    command = "interface {name}".format(**config_data)
-    return command
-
-
 def _tmplt_ospf_interface_process(config_data):
     if "process" in config_data:
         if config_data.get("afi") == "ipv4":
-            command = "ip ospf {id} area {area_id}".format(
-                **config_data["process"]
-            )
+            command = "ip ospf {id} area {area_id}".format(**config_data["process"])
         elif config_data.get("afi") == "ipv6":
-            command = "ipv6 ospf {id} area {area_id}".format(
-                **config_data["process"]
-            )
+            command = "ipv6 ospf {id} area {area_id}".format(**config_data["process"])
         if "secondaries" in config_data["process"]:
             command += " secondaries"
     return command
@@ -47,9 +40,7 @@ def _tmplt_ip_ospf_authentication(config_data):
         elif config_data.get("afi") == "ipv6":
             command = "ipv6 ospf authentication"
         if "key_chain" in config_data["authentication"]:
-            command += " key-chain {key_chain}".format(
-                **config_data["authentication"]
-            )
+            command += " key-chain {key_chain}".format(**config_data["authentication"])
         elif "message_digest" in config_data["authentication"]:
             command += " message-digest"
         elif "null" in config_data["authentication"]:
@@ -60,15 +51,11 @@ def _tmplt_ip_ospf_authentication(config_data):
 def _tmplt_ip_ospf_cost(config_data):
     if "cost" in config_data:
         if config_data.get("afi") == "ipv4":
-            command = "ip ospf cost {interface_cost}".format(
-                **config_data["cost"]
-            )
+            command = "ip ospf cost {interface_cost}".format(**config_data["cost"])
         elif config_data.get("afi") == "ipv6":
             command = "ipv6 ospf cost"
             if "interface_cost" in config_data["cost"]:
-                command = "ipv6 ospf cost {interface_cost}".format(
-                    **config_data["cost"]
-                )
+                command = "ipv6 ospf cost {interface_cost}".format(**config_data["cost"])
             if "dynamic_cost" in config_data["cost"]:
                 if "default" in config_data["cost"]["dynamic_cost"]:
                     command += " dynamic default {default}".format(
@@ -76,33 +63,21 @@ def _tmplt_ip_ospf_cost(config_data):
                     )
                 elif "hysteresis" in config_data["cost"]["dynamic_cost"]:
                     command += " dynamic hysteresis"
-                    if (
-                        "percent"
-                        in config_data["cost"]["dynamic_cost"]["hysteresis"]
-                    ):
+                    if "percent" in config_data["cost"]["dynamic_cost"]["hysteresis"]:
                         command += " percent {percent}".format(
                             **config_data["cost"]["dynamic_cost"]["hysteresis"]
                         )
-                    elif (
-                        "threshold"
-                        in config_data["cost"]["dynamic_cost"]["hysteresis"]
-                    ):
+                    elif "threshold" in config_data["cost"]["dynamic_cost"]["hysteresis"]:
                         command += " threshold {threshold}".format(
                             **config_data["cost"]["dynamic_cost"]["hysteresis"]
                         )
                 elif "weight" in config_data["cost"]["dynamic_cost"]:
                     command += " dynamic weight"
-                    if (
-                        "l2_factor"
-                        in config_data["cost"]["dynamic_cost"]["weight"]
-                    ):
+                    if "l2_factor" in config_data["cost"]["dynamic_cost"]["weight"]:
                         command += " L2-factor {l2_factor}".format(
                             **config_data["cost"]["dynamic_cost"]["weight"]
                         )
-                    elif (
-                        "latency"
-                        in config_data["cost"]["dynamic_cost"]["weight"]
-                    ):
+                    elif "latency" in config_data["cost"]["dynamic_cost"]["weight"]:
                         command += " latency {latency}".format(
                             **config_data["cost"]["dynamic_cost"]["weight"]
                         )
@@ -111,17 +86,11 @@ def _tmplt_ip_ospf_cost(config_data):
                         and config_data["cost"]["dynamic_cost"]["weight"]["oc"]
                     ):
                         command += " oc cdr"
-                    elif (
-                        "resources"
-                        in config_data["cost"]["dynamic_cost"]["weight"]
-                    ):
+                    elif "resources" in config_data["cost"]["dynamic_cost"]["weight"]:
                         command += " resources {resources}".format(
                             **config_data["cost"]["dynamic_cost"]["weight"]
                         )
-                    elif (
-                        "throughput"
-                        in config_data["cost"]["dynamic_cost"]["weight"]
-                    ):
+                    elif "throughput" in config_data["cost"]["dynamic_cost"]["weight"]:
                         command += " throughput {throughput}".format(
                             **config_data["cost"]["dynamic_cost"]["weight"]
                         )
@@ -139,9 +108,7 @@ def _tmplt_ip_ospf_dead_interval(config_data):
                     **config_data["dead_interval"]
                 )
         elif config_data.get("afi") == "ipv6":
-            command = "ipv6 ospf dead-interval {time}".format(
-                **config_data["dead_interval"]
-            )
+            command = "ipv6 ospf dead-interval {time}".format(**config_data["dead_interval"])
     return command
 
 
@@ -170,19 +137,13 @@ def _tmplt_ip_ospf_manet(config_data):
         if "cost" in config_data["manet"]:
             command += " cost"
             if "percent" in config_data["manet"]["cost"]:
-                command += " percent {percent}".format(
-                    **config_data["manet"]["cost"]
-                )
+                command += " percent {percent}".format(**config_data["manet"]["cost"])
             elif "threshold" in config_data["manet"]["cost"]:
-                command += " threshold {threshold}".format(
-                    **config_data["manet"]["cost"]
-                )
+                command += " threshold {threshold}".format(**config_data["manet"]["cost"])
         elif "link_metrics" in config_data["manet"]:
             command += " link-metrics"
             if "cost_threshold" in config_data["manet"]["link_metrics"]:
-                command += " {cost_threshold}".format(
-                    **config_data["manet"]["link_metrics"]
-                )
+                command += " {cost_threshold}".format(**config_data["manet"]["link_metrics"])
     return command
 
 
@@ -196,24 +157,17 @@ def _tmplt_ip_ospf_multi_area(config_data):
 
 def _tmplt_ip_ospf_neighbor(config_data):
     if "neighbor" in config_data:
-        command = "ipv6 ospf neighbor {address}".format(
-            **config_data["neighbor"]
-        )
+        command = "ipv6 ospf neighbor {address}".format(**config_data["neighbor"])
     if "cost" in config_data["neighbor"]:
         command += " cost {cost}".format(**config_data["neighbor"])
-    if (
-        "database_filter" in config_data["neighbor"]
-        and config_data["neighbor"]["database_filter"]
-    ):
+    if "database_filter" in config_data["neighbor"] and config_data["neighbor"]["database_filter"]:
         command += " database-filter all out"
     if "poll_interval" in config_data["neighbor"]:
         command += " poll-interval {poll_interval}".format(
             **config_data["neighbor"]["poll_interval"]
         )
     if "priority" in config_data["neighbor"]:
-        command += " priority {priority}".format(
-            **config_data["neighbor"]["priority"]
-        )
+        command += " priority {priority}".format(**config_data["neighbor"]["priority"])
     return command
 
 
@@ -246,9 +200,7 @@ def _tmplt_ip_ospf_ttl_security(config_data):
 
 class Ospf_InterfacesTemplate(NetworkTemplate):
     def __init__(self, lines=None, module=None):
-        super(Ospf_InterfacesTemplate, self).__init__(
-            lines=lines, tmplt=self, module=module
-        )
+        super(Ospf_InterfacesTemplate, self).__init__(lines=lines, tmplt=self, module=module)
 
     PARSERS = [
         {
@@ -260,9 +212,7 @@ class Ospf_InterfacesTemplate(NetworkTemplate):
                 re.VERBOSE,
             ),
             "setval": "interface {{ name }}",
-            "result": {
-                "{{ name }}": {"name": "{{ name }}", "address_family": {}}
-            },
+            "result": {"{{ name }}": {"name": "{{ name }}", "address_family": {}}},
             "shared": True,
         },
         {
@@ -291,9 +241,9 @@ class Ospf_InterfacesTemplate(NetworkTemplate):
                                 "secondaries": "{{ True if secondaries is defined }}",
                                 "instance_id": "{{ instance.split(' ')[1]}}",
                             },
-                        }
-                    }
-                }
+                        },
+                    },
+                },
             },
         },
         {
@@ -314,9 +264,9 @@ class Ospf_InterfacesTemplate(NetworkTemplate):
                         "{{ afi }}": {
                             "afi": "{{ 'ipv4' if afi == 'ip' else 'ipv6' }}",
                             "adjacency": "{{ True if adjacency is defined }}",
-                        }
-                    }
-                }
+                        },
+                    },
+                },
             },
         },
         {
@@ -343,9 +293,9 @@ class Ospf_InterfacesTemplate(NetworkTemplate):
                                 "message_digest": "{{ True if message_digest is defined }}",
                                 "null": "{{ True if null is defined }}",
                             },
-                        }
-                    }
-                }
+                        },
+                    },
+                },
             },
         },
         {
@@ -366,9 +316,9 @@ class Ospf_InterfacesTemplate(NetworkTemplate):
                         "{{ afi }}": {
                             "afi": "{{ 'ipv4' if afi == 'ip' else 'ipv6' }}",
                             "bfd": "{{ True if bfd is defined }}",
-                        }
-                    }
-                }
+                        },
+                    },
+                },
             },
         },
         {
@@ -388,12 +338,10 @@ class Ospf_InterfacesTemplate(NetworkTemplate):
                     "address_family": {
                         "{{ afi }}": {
                             "afi": "{{ 'ipv4' if afi == 'ip' else 'ipv6' }}",
-                            "cost": {
-                                "interface_cost": "{{ cost.split(' ')[1] }}"
-                            },
-                        }
-                    }
-                }
+                            "cost": {"interface_cost": "{{ cost.split(' ')[1] }}"},
+                        },
+                    },
+                },
             },
         },
         {
@@ -438,9 +386,9 @@ class Ospf_InterfacesTemplate(NetworkTemplate):
                                     },
                                 },
                             },
-                        }
-                    }
-                }
+                        },
+                    },
+                },
             },
         },
         {
@@ -461,20 +409,18 @@ class Ospf_InterfacesTemplate(NetworkTemplate):
                         "{{ afi }}": {
                             "afi": "{{ 'ipv4' if afi == 'ip' else 'ipv6' }}",
                             "database_filter": "{{ True if database_filter is defined }}",
-                        }
-                    }
-                }
+                        },
+                    },
+                },
             },
         },
         {
             "name": "dead_interval",
             "getval": re.compile(
                 r"""
-                \s+(?P<afi>ip|ipv6)*
-                \s*ospf*
-                \s*(?P<dead_interval>dead-interval)*
-                \s*(?P<seconds>\d+)*
-                \s*(?P<minimal>minimal\shello-multiplier\s\d+)*
+                \s((?P<afi>ip|ipv6)\sospf\sdead-interval)?
+                (\s(?P<seconds>\d+))?
+                (\sminimal\shello-multiplier\s(?P<minimal>\d+))?
                 $""",
                 re.VERBOSE,
             ),
@@ -484,15 +430,10 @@ class Ospf_InterfacesTemplate(NetworkTemplate):
                     "address_family": {
                         "{{ afi }}": {
                             "afi": "{{ 'ipv4' if afi == 'ip' else 'ipv6' }}",
-                            "dead_interval": {
-                                "time": "{{ seconds }}",
-                                "minimal": {
-                                    "hello_multiplier": "{{ minimal.split(' ')[2] }}"
-                                },
-                            },
-                        }
-                    }
-                }
+                            "dead_interval": {"time": "{{ seconds }}", "minimal": "{{ minimal }}"},
+                        },
+                    },
+                },
             },
         },
         {
@@ -518,9 +459,9 @@ class Ospf_InterfacesTemplate(NetworkTemplate):
                                 "ignore": "{{ True if ignore is defined }}",
                                 "disable": "{{ True if disable is defined }}",
                             },
-                        }
-                    }
-                }
+                        },
+                    },
+                },
             },
         },
         {
@@ -540,9 +481,9 @@ class Ospf_InterfacesTemplate(NetworkTemplate):
                         "{{ afi }}": {
                             "afi": "{{ 'ipv4' if afi == 'ip' else 'ipv6' }}",
                             "flood_reduction": "{{ True if flood_reduction is defined }}",
-                        }
-                    }
-                }
+                        },
+                    },
+                },
             },
         },
         {
@@ -562,9 +503,9 @@ class Ospf_InterfacesTemplate(NetworkTemplate):
                         "{{ afi }}": {
                             "afi": "{{ 'ipv4' if afi == 'ip' else 'ipv6' }}",
                             "hello_interval": "{{ hello_interval.split(' ')[1] }}",
-                        }
-                    }
-                }
+                        },
+                    },
+                },
             },
         },
         {
@@ -584,9 +525,9 @@ class Ospf_InterfacesTemplate(NetworkTemplate):
                         "{{ afi }}": {
                             "afi": "{{ 'ipv4' if afi == 'ip' else 'ipv6' }}",
                             "lls": "{{ True if lls is defined }}",
-                        }
-                    }
-                }
+                        },
+                    },
+                },
             },
         },
         {
@@ -617,9 +558,9 @@ class Ospf_InterfacesTemplate(NetworkTemplate):
                                     "cost_threshold": "{{ link_metrics.split(' ')[1] }}",
                                 },
                             },
-                        }
-                    }
-                }
+                        },
+                    },
+                },
             },
         },
         {
@@ -639,9 +580,9 @@ class Ospf_InterfacesTemplate(NetworkTemplate):
                         "{{ afi }}": {
                             "afi": "{{ 'ipv4' if afi == 'ip' else 'ipv6' }}",
                             "mtu_ignore": "{{ True if mtu_ignore is defined }}",
-                        }
-                    }
-                }
+                        },
+                    },
+                },
             },
         },
         {
@@ -665,9 +606,9 @@ class Ospf_InterfacesTemplate(NetworkTemplate):
                                 "id": "{{ multi_area.split(' ')[1] }}",
                                 "cost": "{{ cost.split(' ')[1] }}",
                             },
-                        }
-                    }
-                }
+                        },
+                    },
+                },
             },
         },
         {
@@ -698,9 +639,9 @@ class Ospf_InterfacesTemplate(NetworkTemplate):
                                 "poll_interval": "{{ poll_interval.split(' ')[1] }}",
                                 "priority": "{{ priority.split(' ')[1] }}",
                             },
-                        }
-                    }
-                }
+                        },
+                    },
+                },
             },
         },
         {
@@ -731,9 +672,9 @@ class Ospf_InterfacesTemplate(NetworkTemplate):
                                 "point_to_multipoint": "{{ True if point_to_multipoint is defined }}",
                                 "point_to_point": "{{ True if point_to_point is defined }}",
                             },
-                        }
-                    }
-                }
+                        },
+                    },
+                },
             },
         },
         {
@@ -753,9 +694,9 @@ class Ospf_InterfacesTemplate(NetworkTemplate):
                         "{{ afi }}": {
                             "afi": "{{ 'ipv4' if afi == 'ip' else 'ipv6' }}",
                             "prefix_suppression": "{{ True if prefix_suppression is defined }}",
-                        }
-                    }
-                }
+                        },
+                    },
+                },
             },
         },
         {
@@ -775,9 +716,9 @@ class Ospf_InterfacesTemplate(NetworkTemplate):
                         "{{ afi }}": {
                             "afi": "{{ 'ipv4' if afi == 'ip' else 'ipv6' }}",
                             "priority": "{{ priority.split(' ')[1] }}",
-                        }
-                    }
-                }
+                        },
+                    },
+                },
             },
         },
         {
@@ -797,9 +738,9 @@ class Ospf_InterfacesTemplate(NetworkTemplate):
                         "{{ afi }}": {
                             "afi": "{{ 'ipv4' if afi == 'ip' else 'ipv6' }}",
                             "resync_timeout": "{{ resync_timeout.split(' ')[1] }}",
-                        }
-                    }
-                }
+                        },
+                    },
+                },
             },
         },
         {
@@ -819,9 +760,9 @@ class Ospf_InterfacesTemplate(NetworkTemplate):
                         "{{ afi }}": {
                             "afi": "{{ 'ipv4' if afi == 'ip' else 'ipv6' }}",
                             "retransmit_interval": "{{ retransmit_interval.split(' ')[1] }}",
-                        }
-                    }
-                }
+                        },
+                    },
+                },
             },
         },
         {
@@ -841,9 +782,9 @@ class Ospf_InterfacesTemplate(NetworkTemplate):
                         "{{ afi }}": {
                             "afi": "{{ 'ipv4' if afi == 'ip' else 'ipv6' }}",
                             "shutdown": "{{ True if shutdown is defined }}",
-                        }
-                    }
-                }
+                        },
+                    },
+                },
             },
         },
         {
@@ -863,9 +804,9 @@ class Ospf_InterfacesTemplate(NetworkTemplate):
                         "{{ afi }}": {
                             "afi": "{{ 'ipv4' if afi == 'ip' else 'ipv6' }}",
                             "transmit_delay": "{{ transmit_delay.split(' ')[1] }}",
-                        }
-                    }
-                }
+                        },
+                    },
+                },
             },
         },
         {
@@ -889,9 +830,9 @@ class Ospf_InterfacesTemplate(NetworkTemplate):
                                 "set": "{{ True if hops is not defined and ttl_security is defined }}",
                                 "hops": "{{ hops.split(' ')[1] }}",
                             },
-                        }
-                    }
-                }
+                        },
+                    },
+                },
             },
         },
     ]
