@@ -73,7 +73,7 @@ class TestIosInterfacesModule(TestIosModule):
              no shutdown
              ip address dhcp
              negotiation auto
-            interface GigabitEthernet2
+            interface GigabitEthernet0/1
              description Ansible UT interface 2
              ip address dhcp
              speed 1000
@@ -97,6 +97,8 @@ class TestIosInterfacesModule(TestIosModule):
              duplex full
              negotiation auto
              ipv6 dhcp server
+            interface GigabitEthernet6
+             description Ansible UT interface 6
             """,
         )
         set_module_args(
@@ -110,18 +112,21 @@ class TestIosInterfacesModule(TestIosModule):
                     {
                         "description": "This interface should be enabled",
                         "enabled": False,
-                        "name": "GigabitEthernet2",
+                        "name": "GigabitEthernet0/1",
                     },
+                    {"mode": "layer3", "name": "GigabitEthernet6"},
                 ],
                 "state": "merged",
             },
         )
         commands = [
-            "interface GigabitEthernet1",
-            "description This interface should be disabled",
-            "interface GigabitEthernet2",
+            "interface GigabitEthernet0/1",
             "description This interface should be enabled",
             "shutdown",
+            "interface GigabitEthernet1",
+            "description This interface should be disabled",
+            "interface GigabitEthernet6",
+            "no switchport",
         ]
         result = self.execute_module(changed=True)
         self.assertEqual(result["commands"], commands)
@@ -134,7 +139,7 @@ class TestIosInterfacesModule(TestIosModule):
              no shutdown
              ip address dhcp
              negotiation auto
-            interface GigabitEthernet2
+            interface GigabitEthernet0/1
              description Ansible UT interface 2
              ip address dhcp
              speed 1000
@@ -163,13 +168,10 @@ class TestIosInterfacesModule(TestIosModule):
         set_module_args(
             {
                 "config": [
-                    {
-                        "description": "Ansible UT interface 1",
-                        "name": "GigabitEthernet1",
-                    },
+                    {"description": "Ansible UT interface 1", "name": "GigabitEthernet1"},
                     {
                         "description": "Ansible UT interface 2",
-                        "name": "GigabitEthernet2",
+                        "name": "GigabitEthernet0/1",
                         "speed": 1000,
                         "mtu": 1500,
                     },
@@ -187,7 +189,7 @@ class TestIosInterfacesModule(TestIosModule):
              no shutdown
              ip address dhcp
              negotiation auto
-            interface GigabitEthernet2
+            interface GigabitEthernet0/1
              description Ansible UT interface 2
              ip address dhcp
              speed 1000
@@ -211,25 +213,32 @@ class TestIosInterfacesModule(TestIosModule):
              duplex full
              negotiation auto
              ipv6 dhcp server
+            interface GigabitEthernet6
+             description Ansible UT interface 6
+             no switchport
             """,
         )
         set_module_args(
             {
                 "config": [
+                    {"description": "Ansible UT interface 1", "name": "GigabitEthernet1"},
+                    {"name": "GigabitEthernet0/1", "speed": 1200, "mtu": 1800},
                     {
-                        "description": "Ansible UT interface 1",
-                        "name": "GigabitEthernet1",
+                        "name": "GigabitEthernet6",
+                        "description": "Ansible UT interface 6",
+                        "mode": "layer2",
                     },
-                    {"name": "GigabitEthernet2", "speed": 1200, "mtu": 1800},
                 ],
                 "state": "replaced",
             },
         )
         commands = [
-            "interface GigabitEthernet2",
+            "interface GigabitEthernet0/1",
             "no description Ansible UT interface 2",
             "speed 1200",
             "mtu 1800",
+            "interface GigabitEthernet6",
+            "switchport",
         ]
         result = self.execute_module(changed=True)
         self.assertEqual(result["commands"], commands)
@@ -242,7 +251,7 @@ class TestIosInterfacesModule(TestIosModule):
              no shutdown
              ip address dhcp
              negotiation auto
-            interface GigabitEthernet2
+            interface GigabitEthernet0/1
              description Ansible UT interface 2
              ip address dhcp
              speed 1000
@@ -271,13 +280,10 @@ class TestIosInterfacesModule(TestIosModule):
         set_module_args(
             {
                 "config": [
-                    {
-                        "description": "Ansible UT interface 1",
-                        "name": "GigabitEthernet1",
-                    },
+                    {"description": "Ansible UT interface 1", "name": "GigabitEthernet1"},
                     {
                         "description": "Ansible UT interface 2",
-                        "name": "GigabitEthernet2",
+                        "name": "GigabitEthernet0/1",
                         "speed": 1000,
                         "mtu": 1500,
                     },
@@ -295,7 +301,7 @@ class TestIosInterfacesModule(TestIosModule):
              no shutdown
              ip address dhcp
              negotiation auto
-            interface GigabitEthernet2
+            interface GigabitEthernet0/1
              description Ansible UT interface 2
              ip address dhcp
              speed 1000
@@ -319,6 +325,9 @@ class TestIosInterfacesModule(TestIosModule):
              duplex full
              negotiation auto
              ipv6 dhcp server
+            interface GigabitEthernet6
+             description Ansible UT interface 6
+             no switchport
             """,
         )
         set_module_args(
@@ -341,7 +350,7 @@ class TestIosInterfacesModule(TestIosModule):
         )
 
         commands = [
-            "interface GigabitEthernet2",
+            "interface GigabitEthernet0/1",
             "no description Ansible UT interface 2",
             "no speed 1000",
             "no mtu 1500",
@@ -352,6 +361,10 @@ class TestIosInterfacesModule(TestIosModule):
             "no description Ansible UT interface 5",
             "no duplex full",
             "shutdown",
+            "interface GigabitEthernet6",
+            "no description Ansible UT interface 6",
+            "shutdown",
+            "switchport",
             "interface GigabitEthernet1",
             "description Ansible UT interface try 1",
             "speed 1000",
@@ -373,7 +386,7 @@ class TestIosInterfacesModule(TestIosModule):
              no shutdown
              ip address dhcp
              negotiation auto
-            interface GigabitEthernet2
+            interface GigabitEthernet0/1
              description Ansible UT interface 2
              ip address dhcp
              speed 1000
@@ -399,9 +412,7 @@ class TestIosInterfacesModule(TestIosModule):
              ipv6 dhcp server
             """,
         )
-        set_module_args(
-            dict(config=[dict(name="GigabitEthernet1")], state="deleted"),
-        )
+        set_module_args(dict(config=[dict(name="GigabitEthernet1")], state="deleted"))
         commands = [
             "interface GigabitEthernet1",
             "no description Ansible UT interface 1",
@@ -418,7 +429,7 @@ class TestIosInterfacesModule(TestIosModule):
              no shutdown
              ip address dhcp
              negotiation auto
-            interface GigabitEthernet2
+            interface GigabitEthernet0/1
              description Ansible UT interface 2
              ip address dhcp
              speed 1000
@@ -448,7 +459,7 @@ class TestIosInterfacesModule(TestIosModule):
             dict(
                 config=[
                     {
-                        "name": "GigabitEthernet2",
+                        "name": "GigabitEthernet0/1",
                         "description": "Ansible UT interface 2",
                         "speed": "1000",
                         "mtu": 1500,
@@ -464,10 +475,7 @@ class TestIosInterfacesModule(TestIosModule):
                 state="purged",
             ),
         )
-        commands = [
-            "no interface GigabitEthernet2",
-            "no interface GigabitEthernet3",
-        ]
+        commands = ["no interface GigabitEthernet0/1", "no interface GigabitEthernet3"]
         result = self.execute_module(changed=True)
         self.assertEqual(result["commands"], commands)
 
@@ -479,7 +487,7 @@ class TestIosInterfacesModule(TestIosModule):
              no shutdown
              ip address dhcp
              negotiation auto
-            interface GigabitEthernet2
+            interface GigabitEthernet0/1
              description Ansible UT interface 2
              ip address dhcp
              speed 1000
@@ -507,8 +515,8 @@ class TestIosInterfacesModule(TestIosModule):
         )
         set_module_args(dict(config=[], state="purged"))
         commands = [
+            "no interface GigabitEthernet0/1",
             "no interface GigabitEthernet1",
-            "no interface GigabitEthernet2",
             "no interface GigabitEthernet3",
             "no interface GigabitEthernet4",
             "no interface GigabitEthernet5",
@@ -526,7 +534,7 @@ class TestIosInterfacesModule(TestIosModule):
                      no shutdown
                      ip address dhcp
                      negotiation auto
-                    interface GigabitEthernet2
+                    interface GigabitEthernet0/1
                      description Ansible UT interface 2
                      ip address dhcp
                      speed 1000
@@ -550,6 +558,12 @@ class TestIosInterfacesModule(TestIosModule):
                      duplex full
                      negotiation auto
                      ipv6 dhcp server
+                    interface GigabitEthernet6
+                     description Ansible UT interface 6
+                     switchport
+                    interface GigabitEthernet7
+                     description Ansible UT interface 7
+                     no switchport
                     """,
                 ),
                 state="parsed",
@@ -558,34 +572,38 @@ class TestIosInterfacesModule(TestIosModule):
         result = self.execute_module(changed=False)
         parsed_list = [
             {
-                "name": "GigabitEthernet1",
-                "description": "Ansible UT interface 1",
-                "enabled": True,
-            },
-            {
-                "name": "GigabitEthernet2",
+                "name": "GigabitEthernet0/1",
                 "description": "Ansible UT interface 2",
                 "speed": "1000",
                 "mtu": 1500,
                 "enabled": True,
             },
+            {"name": "GigabitEthernet1", "description": "Ansible UT interface 1", "enabled": True},
             {
                 "name": "GigabitEthernet3",
                 "description": "Ansible UT interface 3",
                 "enabled": False,
                 "duplex": "auto",
             },
-            {
-                "name": "GigabitEthernet4",
-                "description": "Ansible UT interface 4",
-                "enabled": False,
-            },
+            {"name": "GigabitEthernet4", "description": "Ansible UT interface 4", "enabled": False},
             {
                 "name": "GigabitEthernet5",
                 "description": "Ansible UT interface 5",
                 "duplex": "full",
                 "enabled": True,
             },
+            {
+                "name": "GigabitEthernet6",
+                "mode": "layer2",
+                "description": "Ansible UT interface 6",
+                "enabled": True,
+            },
+            {
+                "name": "GigabitEthernet7",
+                "mode": "layer3",
+                "description": "Ansible UT interface 7",
+                "enabled": True,
+            },
         ]
         self.assertEqual(parsed_list, result["parsed"])
 
@@ -594,7 +612,7 @@ class TestIosInterfacesModule(TestIosModule):
             """\
             interface GigabitEthernet1
              description Ansible UT interface 1
-            interface GigabitEthernet2
+            interface GigabitEthernet0/1
              description Ansible UT interface 2
              ip address dhcp
             interface GigabitEthernet3
@@ -614,7 +632,7 @@ class TestIosInterfacesModule(TestIosModule):
                         "enabled": False,
                     },
                     {
-                        "name": "GigabitEthernet2",
+                        "name": "GigabitEthernet0/1",
                         "description": "Ansible UT interface 2",
                         "speed": "1000",
                         "mtu": 1500,
@@ -646,7 +664,7 @@ class TestIosInterfacesModule(TestIosModule):
             "interface GigabitEthernet1",
             "description Ansible UT interface 1",
             "shutdown",
-            "interface GigabitEthernet2",
+            "interface GigabitEthernet0/1",
             "description Ansible UT interface 2",
             "speed 1000",
             "mtu 1500",
