@@ -5,14 +5,15 @@
 
 from __future__ import absolute_import, division, print_function
 
+
 __metaclass__ = type
 
 from textwrap import dedent
-from ansible_collections.cisco.ios.tests.unit.compat.mock import patch
+
 from ansible_collections.cisco.ios.plugins.modules import ios_logging_global
-from ansible_collections.cisco.ios.tests.unit.modules.utils import (
-    set_module_args,
-)
+from ansible_collections.cisco.ios.tests.unit.compat.mock import patch
+from ansible_collections.cisco.ios.tests.unit.modules.utils import set_module_args
+
 from .ios_module import TestIosModule
 
 
@@ -23,39 +24,35 @@ class TestIosLoggingGlobalModule(TestIosModule):
         super(TestIosLoggingGlobalModule, self).setUp()
 
         self.mock_get_config = patch(
-            "ansible_collections.ansible.netcommon.plugins.module_utils.network.common.network.Config.get_config"
+            "ansible_collections.ansible.netcommon.plugins.module_utils.network.common.network.Config.get_config",
         )
         self.get_config = self.mock_get_config.start()
 
         self.mock_load_config = patch(
-            "ansible_collections.ansible.netcommon.plugins.module_utils.network.common.network.Config.load_config"
+            "ansible_collections.ansible.netcommon.plugins.module_utils.network.common.network.Config.load_config",
         )
         self.load_config = self.mock_load_config.start()
 
         self.mock_get_resource_connection_config = patch(
             "ansible_collections.ansible.netcommon.plugins.module_utils.network.common.cfg.base."
-            "get_resource_connection"
-        )
-        self.get_resource_connection_config = (
-            self.mock_get_resource_connection_config.start()
+            "get_resource_connection",
         )
+        self.get_resource_connection_config = self.mock_get_resource_connection_config.start()
 
         self.mock_get_resource_connection_facts = patch(
             "ansible_collections.ansible.netcommon.plugins.module_utils.network.common.rm_base.resource_module_base."
-            "get_resource_connection"
-        )
-        self.get_resource_connection_facts = (
-            self.mock_get_resource_connection_facts.start()
+            "get_resource_connection",
         )
+        self.get_resource_connection_facts = self.mock_get_resource_connection_facts.start()
 
         self.mock_edit_config = patch(
-            "ansible_collections.cisco.ios.plugins.module_utils.network.ios.providers.providers.CliProvider.edit_config"
+            "ansible_collections.cisco.ios.plugins.module_utils.network.ios.providers.providers.CliProvider.edit_config",
         )
         self.edit_config = self.mock_edit_config.start()
 
         self.mock_execute_show_command = patch(
             "ansible_collections.cisco.ios.plugins.module_utils.network.ios.facts.logging_global.logging_global."
-            "Logging_globalFacts.get_logging_data"
+            "Logging_globalFacts.get_logging_data",
         )
         self.execute_show_command = self.mock_execute_show_command.start()
 
@@ -67,43 +64,6 @@ class TestIosLoggingGlobalModule(TestIosModule):
         self.mock_get_config.stop()
         self.mock_load_config.stop()
         self.mock_execute_show_command.stop()
-        self.allCommands = [
-            "logging on",
-            "logging buffered xml 5099 notifications",
-            "logging buginf",
-            "logging cns-events warnings",
-            "logging console xml critical",
-            "logging count",
-            "logging delimiter tcp",
-            "logging discriminator msglog01 severity includes 5",
-            "logging dmvpn rate-limit 10",
-            "logging esm config",
-            "logging exception 4099",
-            "logging facility local5",
-            "logging filter tftp://172.16.2.18/ESM/elate.tcl args TESTInst2",
-            "logging filter tftp://172.16.2.14/ESM/escalate.tcl args TESTInst",
-            "logging history alerts",
-            "logging host 172.16.1.1",
-            "logging host 172.16.1.11 xml",
-            "logging host 172.16.1.25 filtered",
-            "logging host 172.16.1.10 filtered stream 10",
-            "logging host 172.16.1.13 transport tcp port 514",
-            "logging message-counter log",
-            "logging message-counter debug",
-            "logging monitor warnings",
-            "logging origin-id hostname",
-            "logging persistent batch 4444",
-            "logging policy-firewall rate-limit 10",
-            "logging queue-limit esm 150",
-            "logging rate-limit all 2",
-            "logging reload alerts",
-            "logging server-arp",
-            "logging snmp-trap errors",
-            "logging source-interface GBit1/0",
-            "logging source-interface CTunnel2",
-            "logging trap errors",
-            "logging userinfo",
-        ]
 
     def test_ios_logging_global_merged_idempotent(self):
         """
@@ -146,7 +106,7 @@ class TestIosLoggingGlobalModule(TestIosModule):
             logging discriminator msglog01 severity includes 5
             logging filter tftp://172.16.2.18/ESM/elate.tcl args TESTInst2
             logging filter tftp://172.16.2.14/ESM/escalate.tcl args TESTInst
-            """
+            """,
         )
         playbook = dict(
             config=dict(
@@ -163,14 +123,8 @@ class TestIosLoggingGlobalModule(TestIosModule):
                 exception=4099,
                 facility="local5",
                 filter=[
-                    dict(
-                        url="tftp://172.16.2.18/ESM/elate.tcl",
-                        args="TESTInst2",
-                    ),
-                    dict(
-                        url="tftp://172.16.2.14/ESM/escalate.tcl",
-                        args="TESTInst",
-                    ),
+                    dict(url="tftp://172.16.2.18/ESM/elate.tcl", args="TESTInst2"),
+                    dict(url="tftp://172.16.2.14/ESM/escalate.tcl", args="TESTInst"),
                 ],
                 history=dict(severity="alerts"),
                 hosts=[
@@ -178,10 +132,7 @@ class TestIosLoggingGlobalModule(TestIosModule):
                     dict(hostname="172.16.1.11", xml=True),
                     dict(hostname="172.16.1.25", filtered=True),
                     dict(hostname="172.16.1.10", stream=10, filtered=True),
-                    dict(
-                        hostname="172.16.1.13",
-                        transport=dict(tcp=dict(port=514)),
-                    ),
+                    dict(hostname="172.16.1.13", transport=dict(tcp=dict(port=514))),
                 ],
                 message_counter=["log", "debug"],
                 monitor=dict(severity="warnings"),
@@ -193,13 +144,10 @@ class TestIosLoggingGlobalModule(TestIosModule):
                 reload=dict(severity="alerts"),
                 server_arp=True,
                 snmp_trap=["errors"],
-                source_interface=[
-                    dict(interface="GBit1/0"),
-                    dict(interface="CTunnel2"),
-                ],
+                source_interface=[dict(interface="GBit1/0"), dict(interface="CTunnel2")],
                 trap="errors",
                 userinfo=True,
-            )
+            ),
         )
         merged = []
         playbook["state"] = "merged"
@@ -233,7 +181,7 @@ class TestIosLoggingGlobalModule(TestIosModule):
             logging reload alerts
             logging userinfo
             logging trap errors
-            """
+            """,
         )
         playbook = dict(
             config=dict(
@@ -258,7 +206,7 @@ class TestIosLoggingGlobalModule(TestIosModule):
                 server_arp=True,
                 trap="errors",
                 userinfo=True,
-            )
+            ),
         )
         deleted = [
             "no logging on",
@@ -306,38 +254,26 @@ class TestIosLoggingGlobalModule(TestIosModule):
             logging snmp-trap errors
             logging source-interface GBit1/0
             logging source-interface CTunnel2
-            """
+            """,
         )
         playbook = dict(
             config=dict(
                 discriminator=["msglog01 severity includes 5"],
                 filter=[
-                    dict(
-                        url="tftp://172.16.2.18/ESM/elate.tcl",
-                        args="TESTInst2",
-                    ),
-                    dict(
-                        url="tftp://172.16.2.14/ESM/escalate.tcl",
-                        args="TESTInst",
-                    ),
+                    dict(url="tftp://172.16.2.18/ESM/elate.tcl", args="TESTInst2"),
+                    dict(url="tftp://172.16.2.14/ESM/escalate.tcl", args="TESTInst"),
                 ],
                 hosts=[
                     dict(host="172.16.1.1"),
                     dict(hostname="172.16.1.11", xml=True),
                     dict(host="172.16.1.25", filtered=True),
                     dict(hostname="172.16.1.10", stream=10, filtered=True),
-                    dict(
-                        hostname="172.16.1.13",
-                        transport=dict(tcp=dict(port=514)),
-                    ),
+                    dict(hostname="172.16.1.13", transport=dict(tcp=dict(port=514))),
                 ],
                 message_counter=["log", "debug"],
                 snmp_trap=["errors"],
-                source_interface=[
-                    dict(interface="GBit1/0"),
-                    dict(interface="CTunnel2"),
-                ],
-            )
+                source_interface=[dict(interface="GBit1/0"), dict(interface="CTunnel2")],
+            ),
         )
         deleted = [
             "no logging discriminator msglog01 severity includes 5",
@@ -384,38 +320,26 @@ class TestIosLoggingGlobalModule(TestIosModule):
             logging reload alerts
             logging userinfo
             logging trap errors
-            """
+            """,
         )
         playbook = dict(
             config=dict(
                 discriminator=["msglog01 severity includes 5"],
                 filter=[
-                    dict(
-                        url="tftp://172.16.2.18/ESM/elate.tcl",
-                        args="TESTInst2",
-                    ),
-                    dict(
-                        url="tftp://172.16.2.14/ESM/escalate.tcl",
-                        args="TESTInst",
-                    ),
+                    dict(url="tftp://172.16.2.18/ESM/elate.tcl", args="TESTInst2"),
+                    dict(url="tftp://172.16.2.14/ESM/escalate.tcl", args="TESTInst"),
                 ],
                 hosts=[
                     dict(hostname="172.16.1.1"),
                     dict(hostname="172.16.1.11", xml=True),
                     dict(hostname="172.16.1.25", filtered=True),
                     dict(hostname="172.16.1.10", stream=10, filtered=True),
-                    dict(
-                        hostname="172.16.1.13",
-                        transport=dict(tcp=dict(port=514)),
-                    ),
+                    dict(hostname="172.16.1.13", transport=dict(tcp=dict(port=514))),
                 ],
                 message_counter=["log", "debug"],
                 snmp_trap=["errors"],
-                source_interface=[
-                    dict(interface="GBit1/0"),
-                    dict(interface="CTunnel2"),
-                ],
-            )
+                source_interface=[dict(interface="GBit1/0"), dict(interface="CTunnel2")],
+            ),
         )
         overridden = [
             "no logging on",
@@ -466,7 +390,7 @@ class TestIosLoggingGlobalModule(TestIosModule):
             logging monitor critical
             logging buffered xml 5099 warnings
             logging facility local6
-            """
+            """,
         )
         playbook = dict(
             config=dict(
@@ -474,7 +398,7 @@ class TestIosLoggingGlobalModule(TestIosModule):
                 facility="local6",
                 hosts=[dict(host="172.16.1.11", xml=True)],
                 monitor=dict(severity="critical"),
-            )
+            ),
         )
         overridden = []
         playbook["state"] = "overridden"
@@ -487,29 +411,20 @@ class TestIosLoggingGlobalModule(TestIosModule):
         self.execute_show_command.return_value = dedent(
             """\
             logging host 172.16.1.1
-            """
+            """,
         )
         playbook = dict(
             config=dict(
+                monitor=dict(discriminator="TEST"),
                 hosts=[
                     dict(hostname="172.16.2.15", session_id=dict(text="Test")),
                     dict(
                         ipv6="2001:0db8:85a3:0000:0000:8a2e:0370:7304",
                         discriminator="msglog01 severity includes 5",
                     ),
-                    dict(
-                        ipv6="2001:0db8:85a3:0000:0000:8a2e:0370:7314",
-                        sequence_num_session=True,
-                    ),
-                    dict(
-                        ipv6="2001:0db8:85a3:0000:0000:8a2e:0370:7324",
-                        vrf="vpn1",
-                    ),
-                    dict(
-                        ipv6="2001:0db8:85a3:0000:0000:8a2e:0370:7334",
-                        stream=10,
-                        filtered=True,
-                    ),
+                    dict(ipv6="2001:0db8:85a3:0000:0000:8a2e:0370:7314", sequence_num_session=True),
+                    dict(ipv6="2001:0db8:85a3:0000:0000:8a2e:0370:7324", vrf="vpn1"),
+                    dict(ipv6="2001:0db8:85a3:0000:0000:8a2e:0370:7334", stream=10, filtered=True),
                     dict(
                         ipv6="2001:0db8:85a3:0000:0000:8a2e:0370:7344",
                         session_id=dict(tag="ipv4"),
@@ -521,11 +436,7 @@ class TestIosLoggingGlobalModule(TestIosModule):
                     dict(
                         ipv6="2001:0db8:85a3:0000:0000:8a2e:0370:7374",
                         vrf="Apn2",
-                        transport=dict(
-                            udp=dict(
-                                discriminator="msglog01 severity includes 5"
-                            )
-                        ),
+                        transport=dict(udp=dict(discriminator="msglog01 severity includes 5")),
                     ),
                     dict(
                         ipv6="2001:0db8:85a3:0000:0000:8a2e:0370:7384",
@@ -539,13 +450,14 @@ class TestIosLoggingGlobalModule(TestIosModule):
                                 filtered=True,
                                 stream=10,
                                 session_id=dict(text="Test"),
-                            )
+                            ),
                         ),
                     ),
-                ]
-            )
+                ],
+            ),
         )
         merged = [
+            "logging monitor discriminator TEST",
             "logging host 172.16.2.15 session-id string Test",
             "logging host ipv6 2001:0db8:85a3:0000:0000:8a2e:0370:7304 discriminator msglog01 severity includes 5",
             "logging host ipv6 2001:0db8:85a3:0000:0000:8a2e:0370:7314 sequence-num-session",
@@ -577,10 +489,10 @@ class TestIosLoggingGlobalModule(TestIosModule):
                     logging count
                     logging delimiter tcp
                     logging host 172.16.2.15 session-id string Test
-                    """
+                    """,
                 ),
                 state="parsed",
-            )
+            ),
         )
         parsed = dict(
             logging_on="enable",
@@ -600,7 +512,7 @@ class TestIosLoggingGlobalModule(TestIosModule):
         self.execute_show_command.return_value = dedent(
             """\
             logging persistent notify
-            """
+            """,
         )
         set_module_args(dict(state="gathered"))
         gathered = dict(persistent=dict(notify=True))
@@ -612,18 +524,12 @@ class TestIosLoggingGlobalModule(TestIosModule):
     def test_ios_logging_global_gathered_host(self):
         self.execute_show_command.return_value = dedent(
             """\
-            logging host 172.16.1.1 vrf vpn1 transport tcp audit
-            """
+            logging host 172.16.1.1 vrf vpn-1 transport tcp audit
+            """,
         )
         set_module_args(dict(state="gathered"))
         gathered = dict(
-            hosts=[
-                dict(
-                    hostname="172.16.1.1",
-                    vrf="vpn1",
-                    transport=dict(tcp=dict(audit=True)),
-                )
-            ]
+            hosts=[dict(hostname="172.16.1.1", vrf="vpn-1", transport=dict(tcp=dict(audit=True)))],
         )
         result = self.execute_module(changed=False)
 
@@ -634,9 +540,7 @@ class TestIosLoggingGlobalModule(TestIosModule):
         set_module_args(
             dict(
                 config=dict(
-                    rate_limit=dict(
-                        console=True, size=2, except_severity="warnings"
-                    ),
+                    rate_limit=dict(console=True, size=2, except_severity="warnings"),
                     reload=dict(message_limit=10, severity="alerts"),
                     persistent=dict(
                         url="flash0:172.16.0.1",
@@ -646,20 +550,16 @@ class TestIosLoggingGlobalModule(TestIosModule):
                         notify=True,
                     ),
                     queue_limit=dict(trap=1000),
-                    buffered=dict(
-                        discriminator="notifications", filtered=True
-                    ),
+                    buffered=dict(discriminator="notifications", filtered=True),
                     hosts=[
                         dict(
                             ipv6="2001:0db8:85a3:0000:0000:8a2e:0370:7364",
-                            transport=dict(
-                                tcp=dict(session_id=dict(tag="hostname"))
-                            ),
-                        )
+                            transport=dict(tcp=dict(session_id=dict(tag="hostname"))),
+                        ),
                     ],
                 ),
                 state="rendered",
-            )
+            ),
         )
         rendered = [
             "logging reload message-limit 10 alerts",
@@ -686,7 +586,7 @@ class TestIosLoggingGlobalModule(TestIosModule):
             logging persistent size 1000 filesize 1000
             logging source-interface Gbit0/1 vrf vpn1
             logging filter flash:172.16.1.1 1 args Test
-            """
+            """,
         )
         playbook = dict(config=dict())
         deleted = [
@@ -719,7 +619,7 @@ class TestIosLoggingGlobalModule(TestIosModule):
             no logging monitor
             no logging cns-events
             no logging trap
-            """
+            """,
         )
         playbook = dict(config=dict())
         deleted = []
@@ -734,19 +634,12 @@ class TestIosLoggingGlobalModule(TestIosModule):
         self.execute_show_command.return_value = dedent(
             """\
             logging host 172.16.1.1
-            """
+            """,
         )
         playbook = dict(
-            config=dict(
-                hosts=[
-                    dict(hostname="172.16.2.15", session_id=dict(text="Test"))
-                ]
-            )
+            config=dict(hosts=[dict(hostname="172.16.2.15", session_id=dict(text="Test"))]),
         )
-        replaced = [
-            "no logging host 172.16.1.1",
-            "logging host 172.16.2.15 session-id string Test",
-        ]
+        replaced = ["no logging host 172.16.1.1", "logging host 172.16.2.15 session-id string Test"]
         playbook["state"] = "replaced"
         set_module_args(playbook)
         result = self.execute_module(changed=True)
@@ -765,7 +658,7 @@ class TestIosLoggingGlobalModule(TestIosModule):
             logging source-interface GigabitEthernet0 vrf Mgmt-intf
             logging host 172.16.0.1 transport udp port 10000
             logging host 172.16.0.2
-            """
+            """,
         )
         playbook = {
             "config": {
@@ -777,16 +670,10 @@ class TestIosLoggingGlobalModule(TestIosModule):
                     {"hostname": "172.16.0.4", "vrf": "Mgmt-intf"},
                 ],
                 "origin_id": {"tag": "hostname"},
-                "rate_limit": {
-                    "console": True,
-                    "except_severity": "errors",
-                    "size": 10,
-                },
-                "source_interface": [
-                    {"interface": "GigabitEthernet0", "vrf": "Mgmt-intf"}
-                ],
+                "rate_limit": {"console": True, "except_severity": "errors", "size": 10},
+                "source_interface": [{"interface": "GigabitEthernet0", "vrf": "Mgmt-intf"}],
                 "trap": "informational",
-            }
+            },
         }
         replaced = [
             "logging rate-limit console 10 except errors",
@@ -806,7 +693,7 @@ class TestIosLoggingGlobalModule(TestIosModule):
         self.execute_show_command.return_value = dedent(
             """\
             logging host 172.16.2.15
-            """
+            """,
         )
         playbook = dict(config=dict(hosts=[dict(hostname="172.16.2.15")]))
         replaced = []
