@@ -1,11 +1,12 @@
 from __future__ import (absolute_import, division, print_function)
 import json
-from distutils.version import LooseVersion
 
 from ansible.module_utils._text import to_bytes, to_native
-
+from ansible_collections.containers.podman.plugins.module_utils.podman.common import LooseVersion
 from ansible_collections.containers.podman.plugins.module_utils.podman.common import lower_keys
 from ansible_collections.containers.podman.plugins.module_utils.podman.common import generate_systemd
+from ansible_collections.containers.podman.plugins.module_utils.podman.common import delete_systemd
+
 
 __metaclass__ = type
 
@@ -26,10 +27,15 @@ ARGUMENTS_SPEC_POD = dict(
     recreate=dict(type='bool', default=False),
     add_host=dict(type='list', required=False, elements='str'),
     cgroup_parent=dict(type='str', required=False),
+    cpus=dict(type='str', required=False),
+    cpuset_cpus=dict(type='str', required=False),
+    device=dict(type='list', elements='str', required=False),
+    device_read_bps=dict(type='list', elements='str', required=False),
     dns=dict(type='list', elements='str', required=False),
     dns_opt=dict(type='list', elements='str', required=False),
     dns_search=dict(type='list', elements='str', required=False),
     generate_systemd=dict(type='dict', default={}),
+    gidmap=dict(type='list', elements='str', required=False),
     hostname=dict(type='str', required=False),
     infra=dict(type='bool', required=False),
     infra_conmon_pidfile=dict(type='str', required=False),
@@ -41,12 +47,21 @@ ARGUMENTS_SPEC_POD = dict(
     label_file=dict(type='str', required=False),
     mac_address=dict(type='str', required=False),
     name=dict(type='str', required=True),
-    network=dict(type='str', required=False),
+    network=dict(type='list', elements='str', required=False),
+    network_alias=dict(type='list', elements='str', required=False,
+                       aliases=['network_aliases']),
     no_hosts=dict(type='bool', required=False),
+    pid=dict(type='str', required=False),
     pod_id_file=dict(type='str', required=False),
     publish=dict(type='list', required=False,
                  elements='str', aliases=['ports']),
     share=dict(type='str', required=False),
+    subgidname=dict(type='str', required=False),
+    subuidname=dict(type='str', required=False),
+    uidmap=dict(type='list', elements='str', required=False),
+    userns=dict(type='str', required=False),
+    volume=dict(type='list', elements='str', aliases=['volumes'],
+                required=False),
     executable=dict(type='str', required=False, default='podman'),
     debug=dict(type='bool', default=False),
 )
@@ -123,6 +138,22 @@ class PodmanPodModuleParams:
     def addparam_cgroup_parent(self, c):
         return c + ['--cgroup-parent', self.params['cgroup_parent']]
 
+    def addparam_cpus(self, c):
+        return c + ['--cpus', self.params['cpus']]
+
+    def addparam_cpuset_cpus(self, c):
+        return c + ['--cpuset-cpus', self.params['cpuset_cpus']]
+
+    def addparam_device(self, c):
+        for dev in self.params['device']:
+            c += ['--device', dev]
+        return c
+
+    def addparam_device_read_bps(self, c):
+        for dev in self.params['device_read_bps']:
+            c += ['--device-read-bps', dev]
+        return c
+
     def addparam_dns(self, c):
         for g in self.params['dns']:
             c += ['--dns', g]
@@ -138,6 +169,11 @@ class PodmanPodModuleParams:
             c += ['--dns-search', g]
         return c
 
+    def addparam_gidmap(self, c):
+        for gidmap in self.params['gidmap']:
+            c += ['--gidmap', gidmap]
+        return c
+
     def addparam_hostname(self, c):
         return c + ['--hostname', self.params['hostname']]
 
@@ -177,11 +213,19 @@ class PodmanPodModuleParams:
         return c + ['--name', self.params['name']]
 
     def addparam_network(self, c):
-        return c + ['--network', self.params['network']]
+        return c + ['--network', ",".join(self.params['network'])]
+
+    def addparam_network_aliases(self, c):
+        for alias in self.params['network_aliases']:
+            c += ['--network-alias', alias]
+        return c
 
     def addparam_no_hosts(self, c):
         return c + ["=".join('--no-hosts', self.params['no_hosts'])]
 
+    def addparam_pid(self, c):
+        return c + ['--pid', self.params['pid']]
+
     def addparam_pod_id_file(self, c):
         return c + ['--pod-id-file', self.params['pod_id_file']]
 
@@ -193,6 +237,26 @@ class PodmanPodModuleParams:
     def addparam_share(self, c):
         return c + ['--share', self.params['share']]
 
+    def addparam_subgidname(self, c):
+        return c + ['--subgidname', self.params['subgidname']]
+
+    def addparam_subuidname(self, c):
+        return c + ['--subuidname', self.params['subuidname']]
+
+    def addparam_uidmap(self, c):
+        for uidmap in self.params['uidmap']:
+            c += ['--uidmap', uidmap]
+        return c
+
+    def addparam_userns(self, c):
+        return c + ['--userns', self.params['userns']]
+
+    def addparam_volume(self, c):
+        for vol in self.params['volume']:
+            if vol:
+                c += ['--volume', vol]
+        return c
+
 
 class PodmanPodDefaults:
     def __init__(self, module, podman_version):
@@ -334,6 +398,11 @@ class PodmanPodDiff:
         else:
             before = self.info['labels'] if 'labels' in self.info else {}
         after = self.params['label']
+        # Strip out labels that are coming from systemd files
+        # https://github.com/containers/ansible-podman-collections/issues/276
+        if 'podman_systemd_unit' in before:
+            after.pop('podman_systemd_unit', None)
+            before.pop('podman_systemd_unit', None)
         return self._diff_update_and_compare('label', before, after)
 
     # TODO(sshnaidm): https://github.com/containers/podman/pull/6956
@@ -351,14 +420,18 @@ class PodmanPodDiff:
         # Remove default 'podman' network in v3 for comparison
         if before == ['podman']:
             before = []
-        after = self.params['network']
+        after = self.params['network'] or []
+        # Special case for options for slirp4netns rootless networking from v2
+        if net_mode_before == 'slirp4netns' and 'createcommand' in self.info:
+            cr_com = self.info['createcommand']
+            if '--network' in cr_com:
+                cr_net = cr_com[cr_com.index('--network') + 1].lower()
+                if 'slirp4netns:' in cr_net:
+                    before = [cr_net]
         # Currently supported only 'host' and 'none' network modes idempotency
-        if after in ['bridge', 'host', 'slirp4netns']:
-            net_mode_after = after
-        elif after:
-            after = after.split(",")
-        else:
-            after = []
+        if after in [['bridge'], ['host'], ['slirp4netns']]:
+            net_mode_after = after[0]
+
         if net_mode_after and not before:
             # Remove differences between v1 and v2
             net_mode_after = net_mode_after.replace('bridge', 'default')
@@ -377,17 +450,26 @@ class PodmanPodDiff:
 
     # TODO(sshnaidm) Need to add port ranges support
     def diffparam_publish(self):
+        def compose(p, h):
+            s = ":".join(
+                [str(h["hostport"]), p.replace('/tcp', '')]
+            ).strip(":")
+            if h['hostip']:
+                return ":".join([h['hostip'], s])
+            return s
+
         if not self.infra_info:
             return self._diff_update_and_compare('publish', '', '')
+
         ports = self.infra_info['hostconfig']['portbindings']
-        before = [":".join([
-            j[0]['hostip'],
-            str(j[0]["hostport"]),
-            i.replace('/tcp', '')
-        ]).strip(':') for i, j in ports.items()]
+        before = []
+        for port, hosts in ports.items():
+            if hosts:
+                for h in hosts:
+                    before.append(compose(port, h))
         after = self.params['publish'] or []
         after = [
-            i.replace("/tcp", "").replace("[", "").replace("]", "").strip(":")
+            i.replace("/tcp", "").replace("[", "").replace("]", "")
             for i in after]
         # No support for port ranges yet
         for ports in after:
@@ -413,7 +495,8 @@ class PodmanPodDiff:
             after = self.params['share'].split(",")
         else:
             after = ['uts', 'ipc', 'net']
-            if self.params['network'] == 'host':
+            # TODO: find out why on Ubuntu the 'net' is not present
+            if 'net' not in before:
                 after.remove('net')
 
         before, after = sorted(list(set(before))), sorted(list(set(after)))
@@ -492,6 +575,11 @@ class PodmanPod:
         """Return True if pod is running now."""
         if 'status' in self.info['State']:
             return self.info['State']['status'] == 'Running'
+        # older podman versions (1.6.x) don't have status in 'podman pod inspect'
+        # if other methods fail, use 'podman pod ps'
+        ps_info = self.get_ps()
+        if 'status' in ps_info:
+            return ps_info['status'] == 'Running'
         return self.info['State'] == 'Running'
 
     @property
@@ -517,6 +605,13 @@ class PodmanPod:
             [self.module_params['executable'], b'pod', b'inspect', self.name])
         return json.loads(out) if rc == 0 else {}
 
+    def get_ps(self):
+        """Inspect pod process and gather info about it."""
+        # pylint: disable=unused-variable
+        rc, out, err = self.module.run_command(
+            [self.module_params['executable'], b'pod', b'ps', b'--format', b'json', b'--filter', 'name=' + self.name])
+        return json.loads(out)[0] if rc == 0 else {}
+
     def get_infra_info(self):
         """Inspect pod and gather info about it."""
         if not self.info:
@@ -650,7 +745,10 @@ class PodmanPodManager:
         if self.module.params['debug'] or self.module_params['debug']:
             self.results.update({'podman_version': self.pod.version})
         self.results.update(
-            {'podman_systemd': generate_systemd(self.module, self.module_params, self.name)})
+            {'podman_systemd': generate_systemd(self.module,
+                                                self.module_params,
+                                                self.name,
+                                                self.pod.version)})
 
     def execute(self):
         """Execute the desired action according to map of actions & states."""
@@ -756,6 +854,10 @@ class PodmanPodManager:
         if not self.pod.exists:
             self.results.update({'changed': False})
         elif self.pod.exists:
+            delete_systemd(self.module,
+                           self.module_params,
+                           self.name,
+                           self.pod.version)
             self.pod.delete()
             self.results['actions'].append('deleted %s' % self.pod.name)
             self.results.update({'changed': True})
