@@ -5,14 +5,14 @@
 
 from __future__ import (absolute_import, division, print_function)
 __metaclass__ = type
-import json
 import pytest
 
+from ansible.module_utils import basic
 from ansible_collections.netapp.ontap.tests.unit.compat import unittest
 from ansible_collections.netapp.ontap.tests.unit.compat.mock import patch, call
-from ansible.module_utils import basic
-from ansible.module_utils._text import to_bytes
 import ansible_collections.netapp.ontap.plugins.module_utils.netapp as netapp_utils
+from ansible_collections.netapp.ontap.tests.unit.plugins.module_utils.ansible_mocks import set_module_args,\
+    AnsibleFailJson, AnsibleExitJson, patch_ansible
 
 from ansible_collections.netapp.ontap.plugins.modules.na_ontap_firmware_upgrade\
     import NetAppONTAPFirmwareUpgrade as my_module  # module under test
@@ -21,35 +21,6 @@ if not netapp_utils.has_netapp_lib():
     pytestmark = pytest.mark.skip('skipping as missing required netapp_lib')
 
 
-def set_module_args(args):
-    """prepare arguments so that they will be picked up during module creation"""
-    args = json.dumps({'ANSIBLE_MODULE_ARGS': args})
-    basic._ANSIBLE_ARGS = to_bytes(args)  # pylint: disable=protected-access
-
-
-class AnsibleExitJson(Exception):
-    """Exception class to be raised by module.exit_json and caught by the test case"""
-    pass
-
-
-class AnsibleFailJson(Exception):
-    """Exception class to be raised by module.fail_json and caught by the test case"""
-    pass
-
-
-def exit_json(*args, **kwargs):  # pylint: disable=unused-argument
-    """function to patch over exit_json; package return data into an exception"""
-    if 'changed' not in kwargs:
-        kwargs['changed'] = False
-    raise AnsibleExitJson(kwargs)
-
-
-def fail_json(*args, **kwargs):  # pylint: disable=unused-argument
-    """function to patch over fail_json; package return data into an exception"""
-    kwargs['failed'] = True
-    raise AnsibleFailJson(kwargs)
-
-
 def mock_warn(me, log):
     print('WARNING', log)
 
@@ -155,11 +126,6 @@ class TestMyModule(unittest.TestCase):
     ''' a group of related Unit Tests '''
 
     def setUp(self):
-        self.mock_module_helper = patch.multiple(basic.AnsibleModule,
-                                                 exit_json=exit_json,
-                                                 fail_json=fail_json)
-        self.mock_module_helper.start()
-        self.addCleanup(self.mock_module_helper.stop)
         self.server = MockONTAPConnection()
         self.use_vsim = False
 
@@ -253,10 +219,9 @@ class TestMyModule(unittest.TestCase):
         print('Info: test_acp_firmware_upgrade_required_get: %s' % repr(acp_firmware_update_required))
         assert acp_firmware_update_required is True
 
-    @patch('ansible_collections.netapp.ontap.plugins.module_utils.netapp.ems_log_event_cserver')
     @patch('ansible_collections.netapp.ontap.plugins.modules.na_ontap_firmware_upgrade.NetAppONTAPFirmwareUpgrade.sp_firmware_image_update')
     @patch('ansible_collections.netapp.ontap.plugins.modules.na_ontap_firmware_upgrade.NetAppONTAPFirmwareUpgrade.sp_firmware_image_update_progress_get')
-    def test_ensure_apply_for_firmware_upgrade_called(self, get_mock, upgrade_mock, ems_log):
+    def test_ensure_apply_for_firmware_upgrade_called(self, get_mock, upgrade_mock):
         ''' updgrading firmware and checking idempotency '''
         module_args = {}
         module_args.update(self.set_default_args())
@@ -279,9 +244,8 @@ class TestMyModule(unittest.TestCase):
         assert exc.value.args[0]['changed']
         upgrade_mock.assert_called_with()
 
-    @patch('ansible_collections.netapp.ontap.plugins.module_utils.netapp.ems_log_event_cserver')
     @patch('ansible_collections.netapp.ontap.plugins.modules.na_ontap_firmware_upgrade.NetAppONTAPFirmwareUpgrade.shelf_firmware_upgrade')
-    def test_shelf_firmware_upgrade(self, upgrade_mock, ems_log):
+    def test_shelf_firmware_upgrade(self, upgrade_mock):
         ''' Test shelf firmware upgrade '''
         module_args = {}
         module_args.update(self.set_default_args())
@@ -296,9 +260,8 @@ class TestMyModule(unittest.TestCase):
         assert not exc.value.args[0]['changed']
         assert not upgrade_mock.called
 
-    @patch('ansible_collections.netapp.ontap.plugins.module_utils.netapp.ems_log_event_cserver')
     @patch('ansible_collections.netapp.ontap.plugins.modules.na_ontap_firmware_upgrade.NetAppONTAPFirmwareUpgrade.shelf_firmware_upgrade')
-    def test_shelf_firmware_upgrade_force(self, upgrade_mock, ems_log):
+    def test_shelf_firmware_upgrade_force(self, upgrade_mock):
         ''' Test shelf firmware upgrade '''
         module_args = {}
         module_args.update(self.set_default_args())
@@ -315,10 +278,9 @@ class TestMyModule(unittest.TestCase):
         assert exc.value.args[0]['changed']
         assert upgrade_mock.called
 
-    @patch('ansible_collections.netapp.ontap.plugins.module_utils.netapp.ems_log_event_cserver')
     @patch('ansible_collections.netapp.ontap.plugins.modules.na_ontap_firmware_upgrade.NetAppONTAPFirmwareUpgrade.shelf_firmware_upgrade')
     @patch('ansible_collections.netapp.ontap.plugins.modules.na_ontap_firmware_upgrade.NetAppONTAPFirmwareUpgrade.shelf_firmware_update_required')
-    def test_shelf_firmware_upgrade_force_update_required(self, update_required_mock, upgrade_mock, ems_log):
+    def test_shelf_firmware_upgrade_force_update_required(self, update_required_mock, upgrade_mock):
         ''' Test shelf firmware upgrade '''
         module_args = {}
         module_args.update(self.set_default_args())
@@ -337,9 +299,8 @@ class TestMyModule(unittest.TestCase):
         assert exc.value.args[0]['changed']
         assert upgrade_mock.called
 
-    @patch('ansible_collections.netapp.ontap.plugins.module_utils.netapp.ems_log_event_cserver')
     @patch('ansible_collections.netapp.ontap.plugins.modules.na_ontap_firmware_upgrade.NetAppONTAPFirmwareUpgrade.acp_firmware_upgrade')
-    def test_acp_firmware_upgrade(self, upgrade_mock, ems_log):
+    def test_acp_firmware_upgrade(self, upgrade_mock):
         ''' Test ACP firmware upgrade '''
         module_args = {}
         module_args.update(self.set_default_args())
@@ -354,9 +315,8 @@ class TestMyModule(unittest.TestCase):
         assert not exc.value.args[0]['changed']
         assert not upgrade_mock.called
 
-    @patch('ansible_collections.netapp.ontap.plugins.module_utils.netapp.ems_log_event_cserver')
     @patch('ansible_collections.netapp.ontap.plugins.modules.na_ontap_firmware_upgrade.NetAppONTAPFirmwareUpgrade.acp_firmware_upgrade')
-    def test_acp_firmware_upgrade_force(self, upgrade_mock, ems_log):
+    def test_acp_firmware_upgrade_force(self, upgrade_mock):
         ''' Test ACP firmware upgrade '''
         module_args = {}
         module_args.update(self.set_default_args())
@@ -372,9 +332,8 @@ class TestMyModule(unittest.TestCase):
         assert exc.value.args[0]['changed']
         assert upgrade_mock.called
 
-    @patch('ansible_collections.netapp.ontap.plugins.module_utils.netapp.ems_log_event_cserver')
     @patch('ansible_collections.netapp.ontap.plugins.modules.na_ontap_firmware_upgrade.NetAppONTAPFirmwareUpgrade.disk_firmware_upgrade')
-    def test_disk_firmware_upgrade(self, upgrade_mock, ems_log):
+    def test_disk_firmware_upgrade(self, upgrade_mock):
         ''' Test disk firmware upgrade '''
         module_args = {}
         module_args.update(self.set_default_args())
@@ -389,9 +348,8 @@ class TestMyModule(unittest.TestCase):
         assert not exc.value.args[0]['changed']
         assert not upgrade_mock.called
 
-    @patch('ansible_collections.netapp.ontap.plugins.module_utils.netapp.ems_log_event_cserver')
     @patch('ansible_collections.netapp.ontap.plugins.modules.na_ontap_firmware_upgrade.NetAppONTAPFirmwareUpgrade.disk_firmware_upgrade')
-    def test_disk_firmware_upgrade_force(self, upgrade_mock, ems_log):
+    def test_disk_firmware_upgrade_force(self, upgrade_mock):
         ''' Test disk firmware upgrade '''
         module_args = {}
         module_args.update(self.set_default_args())
@@ -407,10 +365,9 @@ class TestMyModule(unittest.TestCase):
         assert exc.value.args[0]['changed']
         assert upgrade_mock.called
 
-    @patch('ansible_collections.netapp.ontap.plugins.module_utils.netapp.ems_log_event_cserver')
     @patch('ansible_collections.netapp.ontap.plugins.modules.na_ontap_firmware_upgrade.NetAppONTAPFirmwareUpgrade.disk_firmware_upgrade')
     @patch('ansible_collections.netapp.ontap.plugins.modules.na_ontap_firmware_upgrade.NetAppONTAPFirmwareUpgrade.disk_firmware_update_required')
-    def test_disk_firmware_upgrade_force_update_required(self, update_required_mock, upgrade_mock, ems_log):
+    def test_disk_firmware_upgrade_force_update_required(self, update_required_mock, upgrade_mock):
         ''' Test disk firmware upgrade '''
         module_args = {}
         module_args.update(self.set_default_args())
@@ -515,8 +472,7 @@ class TestMyModule(unittest.TestCase):
         msg = "Error fetching shelf module firmware  details: NetApp API failed. Reason - None:None"
         assert msg in exc.value.args[0]['msg']
 
-    @patch('ansible_collections.netapp.ontap.plugins.module_utils.netapp.ems_log_event_cserver')
-    def test_firmware_download(self, ems_log):
+    def test_firmware_download(self):
         ''' Test firmware download '''
         module_args = {}
         module_args.update(self.set_default_args())
@@ -531,8 +487,7 @@ class TestMyModule(unittest.TestCase):
         msg = "Firmware download completed.  Extra info: Download complete."
         assert exc.value.args[0]['msg'] == msg
 
-    @patch('ansible_collections.netapp.ontap.plugins.module_utils.netapp.ems_log_event_cserver')
-    def test_60(self, mock_ems_log):
+    def test_60(self):
         ''' Test firmware download '''
         module_args = {}
         module_args.update(self.set_default_args())
@@ -547,8 +502,7 @@ class TestMyModule(unittest.TestCase):
         msg = "Firmware download completed, slowly."
         assert exc.value.args[0]['msg'] == msg
 
-    @patch('ansible_collections.netapp.ontap.plugins.module_utils.netapp.ems_log_event_cserver')
-    def test_firmware_download_502(self, mock_ems_log):
+    def test_firmware_download_502(self):
         ''' Test firmware download '''
         module_args = {}
         module_args.update(self.set_default_args())
@@ -563,8 +517,7 @@ class TestMyModule(unittest.TestCase):
         msg = "Firmware download still in progress."
         assert exc.value.args[0]['msg'] == msg
 
-    @patch('ansible_collections.netapp.ontap.plugins.module_utils.netapp.ems_log_event_cserver')
-    def test_firmware_download_502_as_error(self, mock_ems_log):
+    def test_firmware_download_502_as_error(self):
         ''' Test firmware download '''
         module_args = {}
         module_args.update(self.set_default_args())
@@ -579,8 +532,7 @@ class TestMyModule(unittest.TestCase):
         msg = "NetApp API failed. Reason - 502:Bad GW"
         assert msg in exc.value.args[0]['msg']
 
-    @patch('ansible_collections.netapp.ontap.plugins.module_utils.netapp.ems_log_event_cserver')
-    def test_firmware_download_no_num_error(self, mock_ems_log):
+    def test_firmware_download_no_num_error(self):
         ''' Test firmware download '''
         module_args = {}
         module_args.update(self.set_default_args())
@@ -594,8 +546,7 @@ class TestMyModule(unittest.TestCase):
         msg = "NetApp API failed. Reason - some error string:whatever"
         assert msg in exc.value.args[0]['msg']
 
-    @patch('ansible_collections.netapp.ontap.plugins.module_utils.netapp.ems_log_event_cserver')
-    def test_firmware_download_no_status_attr(self, ems_log):
+    def test_firmware_download_no_status_attr(self):
         ''' Test firmware download '''
         module_args = {}
         module_args.update(self.set_default_args())
@@ -609,8 +560,7 @@ class TestMyModule(unittest.TestCase):
         msg = "unable to download package from dummy_url: 'status' attribute missing."
         assert exc.value.args[0]['msg'].startswith(msg)
 
-    @patch('ansible_collections.netapp.ontap.plugins.module_utils.netapp.ems_log_event_cserver')
-    def test_firmware_download_status_failed(self, ems_log):
+    def test_firmware_download_status_failed(self):
         ''' Test firmware download '''
         module_args = {}
         module_args.update(self.set_default_args())
@@ -624,8 +574,7 @@ class TestMyModule(unittest.TestCase):
         msg = "unable to download package from dummy_url: check 'status' value."
         assert exc.value.args[0]['msg'].startswith(msg)
 
-    @patch('ansible_collections.netapp.ontap.plugins.module_utils.netapp.ems_log_event_cserver')
-    def test_firmware_download_empty_output(self, ems_log):
+    def test_firmware_download_empty_output(self):
         ''' Test firmware download '''
         module_args = {}
         module_args.update(self.set_default_args())
@@ -676,16 +625,6 @@ SRR = {
 }
 
 
-# using pytest natively, without unittest.TestCase
-@pytest.fixture
-def patch_ansible():
-    with patch.multiple(basic.AnsibleModule,
-                        exit_json=exit_json,
-                        fail_json=fail_json,
-                        warn=mock_warn) as mocks:
-        yield mocks
-
-
 def set_default_module_args(use_rest='always'):
     hostname = 'hostname'
     username = 'username'
@@ -719,7 +658,7 @@ def test_rest_successfully_download(mock_request, patch_ansible):
     assert exc.value.args[0]['changed']
     print(mock_request.call_args)
     json = {'url': 'https://download.site.com'}
-    expected = call('POST', 'cluster/software/download', None, json=json, headers=None)
+    expected = call('POST', 'cluster/software/download', None, json=json, headers=None, files=None)
     assert mock_request.call_args == expected
     data['server_username'] = 'user'
     data['server_password'] = 'pass'
@@ -728,7 +667,7 @@ def test_rest_successfully_download(mock_request, patch_ansible):
         my_module().apply()
     print(mock_request.call_args)
     json = {'url': 'https://download.site.com', 'username': 'user', 'password': 'pass'}
-    expected = call('POST', 'cluster/software/download', None, json=json, headers=None)
+    expected = call('POST', 'cluster/software/download', None, json=json, headers=None, files=None)
     assert mock_request.call_args == expected
 
 
