@@ -13,7 +13,7 @@ import sys
 from ansible_collections.netapp.ontap.tests.unit.compat.mock import patch
 import ansible_collections.netapp.ontap.plugins.module_utils.netapp as netapp_utils
 from ansible_collections.netapp.ontap.tests.unit.plugins.module_utils.ansible_mocks import \
-    assert_warning_was_raised, call_main, clear_warnings, create_and_apply, create_module, expect_and_capture_ansible_exception, patch_ansible
+    assert_warning_was_raised, call_main, clear_warnings, create_and_apply, create_module, expect_and_capture_ansible_exception, patch_ansible, print_warnings
 from ansible_collections.netapp.ontap.tests.unit.framework.mock_rest_and_zapi_requests import \
     patch_request_and_invoke, register_responses
 from ansible_collections.netapp.ontap.tests.unit.framework.rest_factory import rest_responses
@@ -77,7 +77,10 @@ SRR = rest_responses({
                                     "cifs": {"enabled": True, "allowed": True},
                                     "iscsi": {"enabled": True, "allowed": True},
                                     "fcp": {"enabled": False},
-                                    "nvme": {"enabled": False}}]}, None),
+                                    "nvme": {"enabled": False},
+                                    "language": "de.utf_8",
+                                    "uuid": "svm_uuid"
+                                    }]}, None),
     'cli_record': (200,
                    {'records': [{"max_volumes": 100, "allowed_protocols": ['nfs', 'iscsi']}]}, None),
     'certificate_record_1': (200,
@@ -169,8 +172,6 @@ def test_successful_create_zapi():
     register_responses([
         ('GET', 'cluster', SRR['is_zapi']),
         ('ZAPI', 'vserver-get-iter', ZRR['no_records']),
-        ('ZAPI', 'ems-autosupport-log', ZRR['success']),
-        ('ZAPI', 'vserver-get-iter', ZRR['no_records']),
         ('ZAPI', 'vserver-create', ZRR['success']),
         ('ZAPI', 'vserver-modify', ZRR['success']),
     ])
@@ -181,8 +182,6 @@ def test_create_idempotency():
     '''Test API create'''
     register_responses([
         ('GET', 'cluster', SRR['is_zapi']),
-        ('ZAPI', 'vserver-get-iter', ZRR['no_records']),
-        ('ZAPI', 'ems-autosupport-log', ZRR['success']),
         ('ZAPI', 'vserver-get-iter', ZRR['svm_record']),
     ])
     assert not create_and_apply(svm_module, DEFAULT_ARGS)['changed']
@@ -193,8 +192,6 @@ def test_create_error():
     register_responses([
         ('GET', 'cluster', SRR['is_zapi']),
         ('ZAPI', 'vserver-get-iter', ZRR['no_records']),
-        ('ZAPI', 'ems-autosupport-log', ZRR['success']),
-        ('ZAPI', 'vserver-get-iter', ZRR['no_records']),
         ('ZAPI', 'vserver-create', ZRR['error']),
     ])
     msg = 'Error provisioning SVM test_svm: NetApp API failed. Reason - 12345:synthetic error for UT purpose'
@@ -205,8 +202,6 @@ def test_successful_delete():
     '''Test successful delete'''
     register_responses([
         ('GET', 'cluster', SRR['is_zapi']),
-        ('ZAPI', 'vserver-get-iter', ZRR['no_records']),
-        ('ZAPI', 'ems-autosupport-log', ZRR['success']),
         ('ZAPI', 'vserver-get-iter', ZRR['svm_record']),
         ('ZAPI', 'vserver-destroy', ZRR['success']),
     ])
@@ -218,8 +213,6 @@ def test_error_delete():
     '''
     register_responses([
         ('GET', 'cluster', SRR['is_zapi']),
-        ('ZAPI', 'vserver-get-iter', ZRR['no_records']),
-        ('ZAPI', 'ems-autosupport-log', ZRR['success']),
         ('ZAPI', 'vserver-get-iter', ZRR['svm_record']),
         ('ZAPI', 'vserver-destroy', ZRR['error']),
     ])
@@ -235,8 +228,6 @@ def test_delete_idempotency():
     register_responses([
         ('GET', 'cluster', SRR['is_zapi']),
         ('ZAPI', 'vserver-get-iter', ZRR['no_records']),
-        ('ZAPI', 'ems-autosupport-log', ZRR['success']),
-        ('ZAPI', 'vserver-get-iter', ZRR['no_records']),
     ])
     module_args = {
         'state': 'absent',
@@ -269,6 +260,7 @@ def test_init_error():
     register_responses([
         ('GET', 'cluster', SRR['is_zapi']),
         ('GET', 'cluster', SRR['is_zapi']),
+        ('GET', 'cluster', SRR['is_rest_96']),
     ])
     module_args = {
         'allowed_protocols': 'dummy,humpty,dumpty,cifs,nfs',
@@ -285,6 +277,11 @@ def test_init_error():
     }
     error = create_module(svm_module, DEFAULT_ARGS, module_args, fail=True)['msg']
     assert error == 'using services requires ONTAP 9.6 or later and REST must be enabled - Unreachable - using ZAPI.'
+    module_args = {
+        'services': {'ndmp': {'allowed': True}},
+    }
+    error = create_module(svm_module, DEFAULT_ARGS, module_args, fail=True)['msg']
+    assert error == 'using ndmp requires ONTAP 9.7 or later and REST must be enabled - ONTAP version: 9.6.0 - using REST.'
 
 
 def test_successful_rename():
@@ -292,8 +289,6 @@ def test_successful_rename():
     register_responses([
         ('GET', 'cluster', SRR['is_zapi']),
         ('ZAPI', 'vserver-get-iter', ZRR['no_records']),
-        ('ZAPI', 'ems-autosupport-log', ZRR['success']),
-        ('ZAPI', 'vserver-get-iter', ZRR['no_records']),
         ('ZAPI', 'vserver-get-iter', ZRR['svm_record']),
         ('ZAPI', 'vserver-rename', ZRR['success']),
     ])
@@ -309,8 +304,6 @@ def test_error_rename_no_from():
     register_responses([
         ('GET', 'cluster', SRR['is_zapi']),
         ('ZAPI', 'vserver-get-iter', ZRR['no_records']),
-        ('ZAPI', 'ems-autosupport-log', ZRR['success']),
-        ('ZAPI', 'vserver-get-iter', ZRR['no_records']),
         ('ZAPI', 'vserver-get-iter', ZRR['no_records']),
     ])
     module_args = {
@@ -326,8 +319,6 @@ def test_error_rename_zapi():
     register_responses([
         ('GET', 'cluster', SRR['is_zapi']),
         ('ZAPI', 'vserver-get-iter', ZRR['no_records']),
-        ('ZAPI', 'ems-autosupport-log', ZRR['success']),
-        ('ZAPI', 'vserver-get-iter', ZRR['no_records']),
         ('ZAPI', 'vserver-get-iter', ZRR['svm_record']),
         ('ZAPI', 'vserver-rename', ZRR['error']),
     ])
@@ -343,8 +334,6 @@ def test_successful_modify_language():
     '''Test successful modify language'''
     register_responses([
         ('GET', 'cluster', SRR['is_zapi']),
-        ('ZAPI', 'vserver-get-iter', ZRR['no_records']),
-        ('ZAPI', 'ems-autosupport-log', ZRR['success']),
         ('ZAPI', 'vserver-get-iter', ZRR['svm_record']),
         ('ZAPI', 'vserver-modify', ZRR['success']),
     ])
@@ -355,8 +344,6 @@ def test_error_modify_language():
     '''Test error modify language'''
     register_responses([
         ('GET', 'cluster', SRR['is_zapi']),
-        ('ZAPI', 'vserver-get-iter', ZRR['no_records']),
-        ('ZAPI', 'ems-autosupport-log', ZRR['success']),
         ('ZAPI', 'vserver-get-iter', ZRR['svm_record']),
         ('ZAPI', 'vserver-modify', ZRR['error']),
     ])
@@ -371,12 +358,8 @@ def test_error_modify_fixed_properties():
     '''Test error modifying a fixed property'''
     register_responses([
         ('GET', 'cluster', SRR['is_zapi']),
-        ('ZAPI', 'vserver-get-iter', ZRR['no_records']),
-        ('ZAPI', 'ems-autosupport-log', ZRR['success']),
         ('ZAPI', 'vserver-get-iter', ZRR['svm_record']),
         ('GET', 'cluster', SRR['is_zapi']),
-        ('ZAPI', 'vserver-get-iter', ZRR['no_records']),
-        ('ZAPI', 'ems-autosupport-log', ZRR['success']),
         ('ZAPI', 'vserver-get-iter', ZRR['svm_record']),
     ])
     module_args = {
@@ -397,8 +380,6 @@ def test_successful_modify_snapshot_policy():
     '''Test successful modify language'''
     register_responses([
         ('GET', 'cluster', SRR['is_zapi']),
-        ('ZAPI', 'vserver-get-iter', ZRR['no_records']),
-        ('ZAPI', 'ems-autosupport-log', ZRR['success']),
         ('ZAPI', 'vserver-get-iter', ZRR['svm_record']),
         ('ZAPI', 'vserver-modify', ZRR['success']),
     ])
@@ -411,8 +392,6 @@ def test_successful_modify_allowed_protocols():
     '''Test successful modify allowed protocols'''
     register_responses([
         ('GET', 'cluster', SRR['is_zapi']),
-        ('ZAPI', 'vserver-get-iter', ZRR['no_records']),
-        ('ZAPI', 'ems-autosupport-log', ZRR['success']),
         ('ZAPI', 'vserver-get-iter', ZRR['svm_record']),
         ('ZAPI', 'vserver-modify', ZRR['success']),
     ])
@@ -425,8 +404,6 @@ def test_successful_modify_aggr_list():
     '''Test successful modify aggr-list'''
     register_responses([
         ('GET', 'cluster', SRR['is_zapi']),
-        ('ZAPI', 'vserver-get-iter', ZRR['no_records']),
-        ('ZAPI', 'ems-autosupport-log', ZRR['success']),
         ('ZAPI', 'vserver-get-iter', ZRR['svm_record']),
         ('ZAPI', 'vserver-modify', ZRR['success']),
     ])
@@ -439,8 +416,6 @@ def test_successful_modify_aggr_list_star():
     '''Test successful modify aggr-list'''
     register_responses([
         ('GET', 'cluster', SRR['is_zapi']),
-        ('ZAPI', 'vserver-get-iter', ZRR['no_records']),
-        ('ZAPI', 'ems-autosupport-log', ZRR['success']),
         ('ZAPI', 'vserver-get-iter', ZRR['svm_record']),
         ('ZAPI', 'vserver-modify', ZRR['success']),
     ])
@@ -1257,3 +1232,19 @@ def test_add_parameter_to_dict():
     assert test_dict['name'] == 'svm'
     assert test_dict['ipspace_key'] == 'ipspace'
     assert test_dict['max_volumes'] == '3333'
+
+
+def test_rest_language_match():
+    register_responses([
+        ('GET', 'cluster', SRR['is_rest_9_8_0']),
+        ('GET', 'svm/svms', SRR['svm_record_ap']),
+        ('GET', 'private/cli/vserver', SRR['cli_record']),
+        ('PATCH', 'svm/svms/svm_uuid', SRR['success']),
+    ])
+    module_args = {
+        'language': 'de.UTF-8'
+    }
+    assert create_and_apply(svm_module, DEFAULT_ARGS, module_args)['changed']
+    print_warnings()
+    assert_warning_was_raised(
+        'Attempting to change language from ONTAP value de.utf_8 to de.UTF-8.  Use de.utf_8 to suppress this warning and maintain idempotency.')
