@@ -85,6 +85,20 @@ test_region = nb.dcim.regions.get(slug="test-region")
 test_region.parent = parent_region
 test_region.save()
 
+## Create site_groups
+site_groups = [
+    {"name": "Test site_group", "slug": "test-site_group"},
+    {"name": "Parent site_group", "slug": "parent-site_group"},
+    {"name": "Other site_group", "slug": "other-site_group"},
+]
+created_site_groups = make_netbox_calls(nb.dcim.site_groups, site_groups)
+### site_group variables to be used later on
+parent_site_group = nb.dcim.site_groups.get(slug="parent-site_group")
+test_site_group = nb.dcim.site_groups.get(slug="test-site_group")
+
+### Create relationship between site_groups
+test_site_group.parent = parent_site_group
+test_site_group.save()
 
 ## Create SITES and register variables
 sites = [
@@ -93,6 +107,7 @@ sites = [
         "slug": "test-site",
         "tenant": test_tenant.id,
         "region": test_region.id,
+        "site_group": test_site_group.id,
     },
     {"name": "Test Site2", "slug": "test-site2"},
 ]
@@ -275,6 +290,8 @@ devices = [
         "device_role": core_switch.id,
         "site": test_site.id,
         "local_context_data": {"ntp_servers": ["pool.ntp.org"]},
+        "serial": "FAB01234567",
+        "asset_tag": "123456789",
     },
     {
         "name": "TestDeviceR1",
@@ -282,6 +299,7 @@ devices = [
         "device_role": core_switch.id,
         "site": test_site.id,
         "rack": test_rack.id,
+        "serial": "FAB12345678",
     },
     {
         "name": "R1-Device",
@@ -289,6 +307,7 @@ devices = [
         "device_role": core_switch.id,
         "site": test_site2.id,
         "rack": test_rack_site2.id,
+        "asset_tag": "345678901",
     },
     {
         "name": "Test Nexus One",
