@@ -34,7 +34,8 @@ options:
         Possible values for this include all, minimum, config, performance,
         capacity, network, subnet, interfaces, hgroups, pgroups, hosts,
         admins, volumes, snapshots, pods, replication, vgroups, offload, apps,
-        arrays, certs, kmip, clients, policies, dir_snaps and filesystems.
+        arrays, certs, kmip, clients, policies, dir_snaps, filesystems,
+        alerts and virtual_machines.
     type: list
     elements: str
     required: false
@@ -220,6 +221,7 @@ purefa_info:
                 "personality": null,
                 "preferred_array": [],
                 "target_port": [],
+                "vlan": null,
                 "wwn": []
             },
             "docker-host": {
@@ -234,6 +236,7 @@ purefa_info:
                     "CT0.ETH4",
                     "CT1.ETH4"
                 ],
+                "vlan": "any",
                 "wwn": [],
             }
         },
@@ -441,6 +444,10 @@ try:
     from packaging import version
 except ImportError:
     HAS_PACKAGING = False
+try:
+    from purestorage import purestorage
+except ImportError:
+    purestorage = None
 import time
 
 SEC_TO_DAY = 86400000
@@ -464,6 +471,10 @@ PURE_OUI = "naa.624a9370"
 SAFE_MODE_VERSION = "2.10"
 PER_PG_VERSION = "2.13"
 SAML2_VERSION = "2.11"
+NFS_USER_MAP_VERSION = "2.15"
+DEFAULT_PROT_API_VERSION = "2.16"
+VM_VERSION = "2.14"
+VLAN_VERSION = "2.17"
 
 
 def generate_default_dict(module, array):
@@ -473,6 +484,13 @@ def generate_default_dict(module, array):
     default_info["api_versions"] = api_version
     if FILES_API_VERSION in api_version:
         arrayv6 = get_array(module)
+        if VM_VERSION in api_version:
+            default_info["virtual_machines"] = len(
+                arrayv6.get_virtual_machines(vm_type="vvol").items
+            )
+            default_info["virtual_machine_snaps"] = len(
+                arrayv6.get_virtual_machine_snapshots(vm_type="vvol").items
+            )
         default_info["snapshot_policies"] = len(arrayv6.get_policies_snapshot().items)
         default_info["nfs_policies"] = len(arrayv6.get_policies_nfs().items)
         default_info["smb_policies"] = len(arrayv6.get_policies_smb().items)
@@ -562,7 +580,8 @@ def generate_config_dict(module, array):
     config_info = {}
     api_version = array._list_available_rest_versions()
     config_info["console_lock"] = array.get_console_lock_status()["console_lock"]
-    config_info["dns"] = array.get_dns()
+    if NFS_USER_MAP_VERSION not in api_version:
+        config_info["dns"] = array.get_dns()
     config_info["smtp"] = array.list_alert_recipients()
     config_info["snmp"] = array.list_snmp_managers()
     config_info["snmp_v3_engine_id"] = array.get_snmp_engine_id()["engine_id"]
@@ -595,6 +614,26 @@ def generate_config_dict(module, array):
             "slp_enabled": smi_s.slp_enabled,
             "wbem_https_enabled": smi_s.wbem_https_enabled,
         }
+        # Add additional SMI-S section to help with formatting
+        # issues caused by `-` in the dict name.
+        config_info["smi_s"] = {
+            "slp_enabled": smi_s.slp_enabled,
+            "wbem_https_enabled": smi_s.wbem_https_enabled,
+        }
+        if NFS_USER_MAP_VERSION in api_version:
+            config_info["dns"] = {}
+            dns_configs = list(arrayv6.get_dns().items)
+            for config in range(0, len(dns_configs)):
+                config_info["dns"][dns_configs[config].services[0]] = {
+                    "nameservers": dns_configs[config].nameservers,
+                    "domain": dns_configs[config].domain,
+                }
+                try:
+                    config_info["dns"][dns_configs[config].services[0]][
+                        "source"
+                    ] = dns_configs[config].source["name"]
+                except Exception:
+                    pass
         if SAML2_VERSION in api_version:
             config_info["saml2sso"] = {}
             saml2 = list(arrayv6.get_sso_saml2_idps().items)
@@ -640,6 +679,28 @@ def generate_config_dict(module, array):
                     }
             except Exception:
                 module.warn("FA-Files is not enabled on this array")
+        if DEFAULT_PROT_API_VERSION in api_version:
+            config_info["default_protections"] = {}
+            default_prots = list(arrayv6.get_container_default_protections().items)
+            for prot in range(0, len(default_prots)):
+                container = getattr(default_prots[prot], "name", "-")
+                config_info["default_protections"][container] = {
+                    "protections": [],
+                    "type": getattr(default_prots[prot], "type", "array"),
+                }
+                for container_prot in range(
+                    0, len(default_prots[prot].default_protections)
+                ):
+                    config_info["default_protections"][container]["protections"].append(
+                        {
+                            "type": default_prots[prot]
+                            .default_protections[container_prot]
+                            .type,
+                            "name": default_prots[prot]
+                            .default_protections[container_prot]
+                            .name,
+                        }
+                    )
 
     else:
         config_info["directory_service"] = {}
@@ -668,6 +729,13 @@ def generate_config_dict(module, array):
     config_info["scsi_timeout"] = array.get(scsi_timeout=True)["scsi_timeout"]
     if S3_REQUIRED_API_VERSION in api_version:
         config_info["global_admin"] = array.get_global_admin_attributes()
+        if (
+            config_info["global_admin"]["lockout_duration"]
+            and config_info["global_admin"]["lockout_duration"] > 0
+        ):
+            config_info["global_admin"]["lockout_duration"] = int(
+                config_info["global_admin"]["lockout_duration"] / 1000
+            )
     return config_info
 
 
@@ -724,8 +792,13 @@ def generate_pgsnaps_dict(array):
             "suffix": snapshots[snapshot].suffix,
             "snapshot_space": snapshots[snapshot].space.snapshots,
         }
-        if pgsnaps_info[s_name]["destroyed"]:
-            pgsnaps_info[s_name]["time_remaining"] = snapshots[snapshot].time_remaining
+        try:
+            if pgsnaps_info[s_name]["destroyed"]:
+                pgsnaps_info[s_name]["time_remaining"] = snapshots[
+                    snapshot
+                ].time_remaining
+        except AttributeError:
+            pass
         try:
             pgsnaps_info[s_name]["manual_eradication"] = snapshots[
                 snapshot
@@ -760,7 +833,7 @@ def generate_dir_snaps_dict(array):
     return dir_snaps_info
 
 
-def generate_policies_dict(array, quota_available):
+def generate_policies_dict(array, quota_available, nfs_user_mapping):
     policy_info = {}
     policies = list(array.get_policies().items)
     for policy in range(0, len(policies)):
@@ -787,6 +860,11 @@ def generate_policies_dict(array, quota_available):
                 }
                 policy_info[p_name]["rules"].append(smb_rules_dict)
         if policies[policy].policy_type == "nfs":
+            if nfs_user_mapping:
+                nfs_policy = list(array.get_policies_nfs(names=[p_name]).items)[0]
+                policy_info[p_name][
+                    "user_mapping_enabled"
+                ] = nfs_policy.user_mapping_enabled
             rules = list(
                 array.get_policies_nfs_client_rules(policy_names=[p_name]).items
             )
@@ -916,27 +994,32 @@ def generate_capacity_dict(module, array):
     capacity_info = {}
     api_version = array._list_available_rest_versions()
     if V6_MINIMUM_API_VERSION in api_version:
+        new_version = bool(SHARED_CAP_API_VERSION in api_version)
         arrayv6 = get_array(module)
         total_capacity = list(arrayv6.get_arrays().items)[0].capacity
         capacity = list(arrayv6.get_arrays_space().items)[0]
-        capacity_info["provisioned_space"] = getattr(
-            capacity.space, "total_provisioned", 0
-        )
-        capacity_info["free_space"] = total_capacity - getattr(
-            capacity.space, "total_physical", 0
-        )
         capacity_info["total_capacity"] = total_capacity
-        capacity_info["data_reduction"] = getattr(capacity.space, "data_reduction", 0)
-        capacity_info["system_space"] = getattr(capacity.space, "system", 0)
-        capacity_info["volume_space"] = getattr(capacity.space, "unique", 0)
-        capacity_info["shared_space"] = getattr(capacity.space, "shared", 0)
-        capacity_info["snapshot_space"] = getattr(capacity.space, "snapshots", 0)
-        capacity_info["thin_provisioning"] = getattr(
-            capacity.space, "thin_provisioning", 0
-        )
-        capacity_info["total_reduction"] = getattr(capacity.space, "total_reduction", 0)
-        capacity_info["replication"] = getattr(capacity.space, "replication", 0)
-        if SHARED_CAP_API_VERSION in api_version:
+        if new_version:
+            capacity_info["provisioned_space"] = getattr(
+                capacity.space, "total_provisioned", 0
+            )
+            capacity_info["free_space"] = total_capacity - getattr(
+                capacity.space, "total_physical", 0
+            )
+            capacity_info["data_reduction"] = getattr(
+                capacity.space, "data_reduction", 0
+            )
+            capacity_info["system_space"] = getattr(capacity.space, "system", 0)
+            capacity_info["volume_space"] = getattr(capacity.space, "unique", 0)
+            capacity_info["shared_space"] = getattr(capacity.space, "shared", 0)
+            capacity_info["snapshot_space"] = getattr(capacity.space, "snapshots", 0)
+            capacity_info["thin_provisioning"] = getattr(
+                capacity.space, "thin_provisioning", 0
+            )
+            capacity_info["total_reduction"] = getattr(
+                capacity.space, "total_reduction", 0
+            )
+            capacity_info["replication"] = getattr(capacity.space, "replication", 0)
             capacity_info["shared_effective"] = getattr(
                 capacity.space, "shared_effective", 0
             )
@@ -949,6 +1032,19 @@ def generate_capacity_dict(module, array):
             capacity_info["total_effective"] = getattr(
                 capacity.space, "total_effective", 0
             )
+        else:
+            capacity_info["provisioned_space"] = capacity.space["total_provisioned"]
+            capacity_info["free_space"] = (
+                total_capacity - capacity.space["total_physical"]
+            )
+            capacity_info["data_reduction"] = capacity.space["data_reduction"]
+            capacity_info["system_space"] = capacity.space["system"]
+            capacity_info["volume_space"] = capacity.space["unique"]
+            capacity_info["shared_space"] = capacity.space["shared"]
+            capacity_info["snapshot_space"] = capacity.space["snapshots"]
+            capacity_info["thin_provisioning"] = capacity.space["thin_provisioning"]
+            capacity_info["total_reduction"] = capacity.space["total_reduction"]
+            capacity_info["replication"] = capacity.space["replication"]
     elif CAP_REQUIRED_API_VERSION in api_version:
         volumes = array.list_volumes(pending=True)
         capacity_info["provisioned_space"] = sum(item["size"] for item in volumes)
@@ -1322,22 +1418,31 @@ def generate_vol_dict(module, array):
     return volume_info
 
 
-def generate_host_dict(array):
+def generate_host_dict(module, array):
     api_version = array._list_available_rest_versions()
     host_info = {}
     hosts = array.list_hosts()
     for host in range(0, len(hosts)):
         hostname = hosts[host]["name"]
         tports = []
-        host_all_info = array.get_host(hostname, all=True)
+        all_tports = []
+        host_all_info = None
+        try:
+            host_all_info = array.get_host(hostname, all=True)
+        except purestorage.PureHTTPError as err:
+            if err.code == 400:
+                continue
         if host_all_info:
-            tports = host_all_info[0]["target_port"]
+            for tport in range(0, len(host_all_info)):
+                for itport in range(0, len(host_all_info[tport]["target_port"])):
+                    tports.append(host_all_info[tport]["target_port"][itport])
+            all_tports = list(dict.fromkeys(tports))
         host_info[hostname] = {
             "hgroup": hosts[host]["hgroup"],
             "iqn": hosts[host]["iqn"],
             "wwn": hosts[host]["wwn"],
             "personality": array.get_host(hostname, personality=True)["personality"],
-            "target_port": tports,
+            "target_port": all_tports,
             "volumes": [],
         }
         host_connections = array.list_host_connections(hostname)
@@ -1359,6 +1464,13 @@ def generate_host_dict(array):
         for host in range(0, len(hosts)):
             hostname = hosts[host]["name"]
             host_info[hostname]["preferred_array"] = hosts[host]["preferred_array"]
+    if VLAN_VERSION in api_version:
+        arrayv6 = get_array(module)
+        hosts = list(arrayv6.get_hosts().items)
+        for host in range(0, len(hosts)):
+            if hosts[host].is_local:
+                hostname = hosts[host].name
+                host_info[hostname]["vlan"] = getattr(hosts[host], "vlan", None)
     return host_info
 
 
@@ -1380,11 +1492,18 @@ def generate_pgroups_dict(module, array):
             "targets": pgroups[pgroup]["targets"],
             "volumes": pgroups[pgroup]["volumes"],
         }
-        prot_sched = array.get_pgroup(protgroup, schedule=True)
-        prot_reten = array.get_pgroup(protgroup, retention=True)
+        try:
+            prot_sched = array.get_pgroup(protgroup, schedule=True)
+            prot_reten = array.get_pgroup(protgroup, retention=True)
+            snap_transfers = array.get_pgroup(
+                protgroup, snap=True, transfer=True, pending=True
+            )
+        except purestorage.PureHTTPError as err:
+            if err.code == 400:
+                continue
         if prot_sched["snap_enabled"] or prot_sched["replicate_enabled"]:
-            pgroups_info[protgroup]["snap_freqyency"] = prot_sched["snap_frequency"]
-            pgroups_info[protgroup]["replicate_freqyency"] = prot_sched[
+            pgroups_info[protgroup]["snap_frequency"] = prot_sched["snap_frequency"]
+            pgroups_info[protgroup]["replicate_frequency"] = prot_sched[
                 "replicate_frequency"
             ]
             pgroups_info[protgroup]["snap_enabled"] = prot_sched["snap_enabled"]
@@ -1402,9 +1521,6 @@ def generate_pgroups_dict(module, array):
             pgroups_info[protgroup]["days"] = prot_reten["days"]
             pgroups_info[protgroup]["all_for"] = prot_reten["all_for"]
             pgroups_info[protgroup]["target_all_for"] = prot_reten["target_all_for"]
-        snap_transfers = array.get_pgroup(
-            protgroup, snap=True, transfer=True, pending=True
-        )
         pgroups_info[protgroup]["snaps"] = {}
         for snap_transfer in range(0, len(snap_transfers)):
             snap = snap_transfers[snap_transfer]["name"]
@@ -1871,6 +1987,103 @@ def generate_interfaces_dict(array):
     return int_info
 
 
+def generate_vm_dict(array):
+    vm_info = {}
+    virt_machines = list(array.get_virtual_machines(vm_type="vvol").items)
+    for machine in range(0, len(virt_machines)):
+        name = virt_machines[machine].name
+        vm_info[name] = {
+            "vm_type": virt_machines[machine].vm_type,
+            "vm_id": virt_machines[machine].vm_id,
+            "destroyed": virt_machines[machine].destroyed,
+            "created": virt_machines[machine].created,
+            "time_remaining": getattr(virt_machines[machine], "time_remaining", None),
+            "latest_snapshot_name": getattr(
+                virt_machines[machine].recover_context, "name", None
+            ),
+            "latest_snapshot_id": getattr(
+                virt_machines[machine].recover_context, "id", None
+            ),
+        }
+    return vm_info
+
+
+def generate_alerts_dict(array):
+    alerts_info = {}
+    alerts = list(array.get_alerts().items)
+    for alert in range(0, len(alerts)):
+        name = alerts[alert].name
+        try:
+            notified_time = alerts[alert].notified / 1000
+            notified_datetime = time.strftime(
+                "%Y-%m-%d %H:%M:%S", time.localtime(notified_time)
+            )
+        except AttributeError:
+            notified_datetime = ""
+        try:
+            closed_time = alerts[alert].closed / 1000
+            closed_datetime = time.strftime(
+                "%Y-%m-%d %H:%M:%S", time.localtime(closed_time)
+            )
+        except AttributeError:
+            closed_datetime = ""
+        try:
+            updated_time = alerts[alert].updated / 1000
+            updated_datetime = time.strftime(
+                "%Y-%m-%d %H:%M:%S", time.localtime(updated_time)
+            )
+        except AttributeError:
+            updated_datetime = ""
+        try:
+            created_time = alerts[alert].created / 1000
+            created_datetime = time.strftime(
+                "%Y-%m-%d %H:%M:%S", time.localtime(created_time)
+            )
+        except AttributeError:
+            updated_datetime = ""
+        alerts_info[name] = {
+            "flagged": alerts[alert].flagged,
+            "category": alerts[alert].category,
+            "code": alerts[alert].code,
+            "issue": alerts[alert].issue,
+            "kb_url": alerts[alert].knowledge_base_url,
+            "summary": alerts[alert].summary,
+            "id": alerts[alert].id,
+            "state": alerts[alert].state,
+            "severity": alerts[alert].severity,
+            "component_name": alerts[alert].component_name,
+            "component_type": alerts[alert].component_type,
+            "created": created_datetime,
+            "closed": closed_datetime,
+            "notified": notified_datetime,
+            "updated": updated_datetime,
+            "actual": getattr(alerts[alert], "actual", ""),
+            "expected": getattr(alerts[alert], "expected", ""),
+        }
+    return alerts_info
+
+
+def generate_vmsnap_dict(array):
+    vmsnap_info = {}
+    virt_snaps = list(array.get_virtual_machine_snapshots(vm_type="vvol").items)
+    for snap in range(0, len(virt_snaps)):
+        name = virt_snaps[snap].name
+        vmsnap_info[name] = {
+            "vm_type": virt_snaps[snap].vm_type,
+            "vm_id": virt_snaps[snap].vm_id,
+            "destroyed": virt_snaps[snap].destroyed,
+            "created": virt_snaps[snap].created,
+            "time_remaining": getattr(virt_snaps[snap], "time_remaining", None),
+            "latest_pgsnapshot_name": getattr(
+                virt_snaps[snap].recover_context, "name", None
+            ),
+            "latest_pgsnapshot_id": getattr(
+                virt_snaps[snap].recover_context, "id", None
+            ),
+        }
+    return vmsnap_info
+
+
 def main():
     argument_spec = purefa_argument_spec()
     argument_spec.update(
@@ -1909,6 +2122,7 @@ def main():
         "policies",
         "dir_snaps",
         "filesystems",
+        "virtual_machines",
     )
     subset_test = (test in valid_subsets for test in subset)
     if not all(subset_test):
@@ -1934,7 +2148,7 @@ def main():
     if "interfaces" in subset or "all" in subset:
         info["interfaces"] = generate_interfaces_dict(array)
     if "hosts" in subset or "all" in subset:
-        info["hosts"] = generate_host_dict(array)
+        info["hosts"] = generate_host_dict(module, array)
     if "volumes" in subset or "all" in subset:
         info["volumes"] = generate_vol_dict(module, array)
         info["deleted_volumes"] = generate_del_vol_dict(module, array)
@@ -1974,17 +2188,28 @@ def main():
         if "filesystems" in subset or "all" in subset:
             info["filesystems"] = generate_filesystems_dict(array_v6)
         if "policies" in subset or "all" in subset:
+            if NFS_USER_MAP_VERSION in api_version:
+                user_map = True
+            else:
+                user_map = False
             if DIR_QUOTA_API_VERSION in api_version:
                 quota = True
             else:
                 quota = False
-            info["policies"] = generate_policies_dict(array_v6, quota)
+            info["policies"] = generate_policies_dict(array_v6, quota, user_map)
         if "clients" in subset or "all" in subset:
             info["clients"] = generate_clients_dict(array_v6)
         if "dir_snaps" in subset or "all" in subset:
             info["dir_snaps"] = generate_dir_snaps_dict(array_v6)
         if "snapshots" in subset or "all" in subset:
             info["pg_snapshots"] = generate_pgsnaps_dict(array_v6)
+        if "alerts" in subset or "all" in subset:
+            info["alerts"] = generate_alerts_dict(array_v6)
+        if VM_VERSION in api_version and (
+            "virtual_machines" in subset or "all" in subset
+        ):
+            info["virtual_machines"] = generate_vm_dict(array_v6)
+            info["virtual_machines_snaps"] = generate_vmsnap_dict(array_v6)
 
     module.exit_json(changed=False, purefa_info=info)
 
